@@ -37,8 +37,7 @@ import dr.util.Author;
 import dr.util.Citable;
 import dr.util.Citation;
 
-import java.util.ArrayList;
-import java.util.List;
+import java.util.*;
 
 /**
  * @author Filip Bielejec
@@ -171,16 +170,21 @@ public class EpochBranchModel extends AbstractModel implements BranchModel, Cita
     protected void acceptState() {
     }// END: acceptState
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Epoch Branch model";
+    }
 
-    /**
-     * @return a list of citations associated with this object
-     */
     public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(new Citation(new Author[]{new Author("F", "Bielejec"),
-                new Author("P", "Lemey"), new Author("G", "Baele"), new Author("A", "Rambaut"),
-                new Author("MA", "Suchard")}, Citation.Status.IN_PREPARATION));
-        return citations;
+        return Arrays.asList(
+                new Citation(new Author[]{new Author("F", "Bielejec"),
+                        new Author("P", "Lemey"), new Author("G", "Baele"), new Author("A", "Rambaut"),
+                        new Author("MA", "Suchard")}, Citation.Status.IN_PREPARATION));
     }// END: getCitations
 
     private final TreeModel tree;
