@@ -1,7 +1,7 @@
 /*
  * ExternalInternalBranchModel.java
  *
- * Copyright (c) 2002-2013 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -37,7 +37,9 @@ import dr.util.Citable;
 import dr.util.Citation;
 
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Map;
 
 /**
  * @author Andrew Rambaut
@@ -45,7 +47,7 @@ import java.util.List;
  * @author Marc A. Suchard
  * @version $Id$
  */
-public class ExternalInternalBranchModel extends AbstractModel implements BranchModel, Citable {
+public class ExternalInternalBranchModel extends AbstractModel implements BranchModel {
     public ExternalInternalBranchModel(TreeModel tree, SubstitutionModel externalSubstModel, SubstitutionModel internalSubstModel) {
         super("ExternalInternalBranchModel");
 
@@ -113,25 +115,6 @@ public class ExternalInternalBranchModel extends AbstractModel implements Branch
     protected void acceptState() {
     }
 
-    /**
-     * @return a list of citations associated with this object
-     */
-    public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                new Citation(
-                        new Author[]{
-                                new Author("F", "Bielejec"),
-                                new Author("P", "Lemey"),
-                                new Author("A", "Rambaut"),
-                                new Author("MA", "Suchard")
-                        },
-                        Citation.Status.IN_PREPARATION
-                )
-        );
-        return citations;
-    }
-
     private final TreeModel tree;
     private final SubstitutionModel externalSubstModel;
     private final SubstitutionModel internalSubstModel;
