@@ -40,9 +40,7 @@ import dr.evolution.alignment.SitePatterns;
 import dr.evomodel.branchratemodel.BranchRateModel;
 import dr.evomodel.tree.TreeModel;
 import dr.evomodel.treelikelihood.TipStatesModel;
-import dr.inference.model.Likelihood;
-import dr.inference.model.Parameter;
-import dr.inference.model.TestThreadedCompoundLikelihood;
+import dr.inference.model.*;
 import dr.xml.AbstractXMLObjectParser;
 import dr.xml.AttributeRule;
 import dr.xml.ElementRule;
@@ -60,20 +58,21 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
     public static final String CALIBRATE = "calibrate";
     public static final String RETRY = "retry";
 
-    public static final boolean DEBUG = true;
+    public static final boolean DEBUG = false;
 
     public String getParserName() {
         return OPTIMIZED_BEAGLE_TREE_LIKELIHOOD;
     }
 
     protected BeagleTreeLikelihood createTreeLikelihood(PatternList patternList, TreeModel treeModel,
-            BranchModel branchModel,
-            GammaSiteRateModel siteRateModel,
-            BranchRateModel branchRateModel,
-            TipStatesModel tipStatesModel,
-            boolean useAmbiguities, PartialsRescalingScheme scalingScheme,
-            Map<Set<String>, Parameter> partialsRestrictions,
-            XMLObject xo) throws XMLParseException {
+                                                        BranchModel branchModel,
+                                                        GammaSiteRateModel siteRateModel,
+                                                        BranchRateModel branchRateModel,
+                                                        TipStatesModel tipStatesModel,
+                                                        boolean useAmbiguities, PartialsRescalingScheme scalingScheme,
+                                                        boolean delayRescalingUntilUnderflow,
+                                                        Map<Set<String>, Parameter> partialsRestrictions,
+                                                        XMLObject xo) throws XMLParseException {
         return new BeagleTreeLikelihood(
                 patternList,
                 treeModel,
@@ -83,8 +82,9 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
                 tipStatesModel,
                 useAmbiguities,
                 scalingScheme,
+                delayRescalingUntilUnderflow,
                 partialsRestrictions
-                );
+        );
     }
 
     public Object parseXMLObject(XMLObject xo) throws XMLParseException {
@@ -104,8 +104,12 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
         int childCount = xo.getChildCount();
         List<Likelihood> likelihoods = new ArrayList<Likelihood>();
 
+        //TEST
+        List<Likelihood> originalLikelihoods = new ArrayList<Likelihood>();
+
         for (int i = 0; i < childCount; i++) {
             likelihoods.add((Likelihood)xo.getChild(i));
+            originalLikelihoods.add((Likelihood)xo.getChild(i));
         }
 
         if (DEBUG) {
@@ -131,23 +135,25 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
         BranchRateModel[] branchRateModels = new BranchRateModel[childCount];
         boolean[] ambiguities = new boolean[childCount];
         PartialsRescalingScheme[] rescalingSchemes = new PartialsRescalingScheme[childCount];
+        boolean[] isDelayRescalingUntilUnderflow = new boolean[childCount];
         List<Map<Set<String>, Parameter>> partialsRestrictions = new ArrayList<Map<Set<String>, Parameter>>();
         for (int i = 0; i < likelihoods.size(); i++) {
-            patterns[i] = (SitePatterns)((BeagleTreeLikelihood)likelihoods.get(i)).getPatternsList();
+            patterns[i] = (SitePatterns) ((BeagleTreeLikelihood) likelihoods.get(i)).getPatternsList();
             siteCounts[i] = patterns[i].getPatternCount();
-            treeModels[i] = ((BeagleTreeLikelihood)likelihoods.get(i)).getTreeModel();
-            branchModels[i] = ((BeagleTreeLikelihood)likelihoods.get(i)).getBranchModel();
-            siteRateModels[i] = (GammaSiteRateModel) ((BeagleTreeLikelihood)likelihoods.get(i)).getSiteRateModel();
-            branchRateModels[i] = ((BeagleTreeLikelihood)likelihoods.get(i)).getBranchRateModel();
-            ambiguities[i] = ((BeagleTreeLikelihood)likelihoods.get(i)).useAmbiguities();
-            rescalingSchemes[i] = ((BeagleTreeLikelihood)likelihoods.get(i)).getRescalingScheme();
-            partialsRestrictions.add(i, ((BeagleTreeLikelihood)likelihoods.get(i)).getPartialsRestrictions());
+            treeModels[i] = ((BeagleTreeLikelihood) likelihoods.get(i)).getTreeModel();
+            branchModels[i] = ((BeagleTreeLikelihood) likelihoods.get(i)).getBranchModel();
+            siteRateModels[i] = (GammaSiteRateModel) ((BeagleTreeLikelihood) likelihoods.get(i)).getSiteRateModel();
+            branchRateModels[i] = ((BeagleTreeLikelihood) likelihoods.get(i)).getBranchRateModel();
+            ambiguities[i] = ((BeagleTreeLikelihood) likelihoods.get(i)).useAmbiguities();
+            rescalingSchemes[i] = ((BeagleTreeLikelihood) likelihoods.get(i)).getRescalingScheme();
+            isDelayRescalingUntilUnderflow[i] = ((BeagleTreeLikelihood) likelihoods.get(i)).isDelayRescalingUntilUnderflow();
+            partialsRestrictions.add(i, ((BeagleTreeLikelihood) likelihoods.get(i)).getPartialsRestrictions());
         }
 
         if (DEBUG) {
             System.err.println("Pattern counts: ");
             for (int i = 0;i < siteCounts.length; i++) {
-                System.err.print(siteCounts[i] + " ");
+                System.err.println(siteCounts[i] + "   vs.    " + patterns[i].getPatternCount());
             }
             System.err.println();
             System.err.println("Instance counts: ");
@@ -164,6 +170,7 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
 
         TestThreadedCompoundLikelihood compound = new TestThreadedCompoundLikelihood(likelihoods);
         //CompoundLikelihood compound = new CompoundLikelihood(likelihoods);
+        //ThreadedCompoundLikelihood compound = new ThreadedCompoundLikelihood(likelihoods);
 
         if (DEBUG) {
             System.err.println("Timing estimates for each of the " + calibrate + " likelihood calculations:");
@@ -356,6 +363,9 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
         }
         for (int i = 0; i < likelihoods.size(); i++) {
             siteCounts[i] = patterns[i].getPatternCount();
+            if (DEBUG) {
+                System.err.println("Site count " + i + " = " + siteCounts[i]);
+            }
         }
 
         if (DEBUG) {
@@ -381,11 +391,13 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
 
                 BeagleTreeLikelihood treeLikelihood = createTreeLikelihood(
                         subPatterns, treeModels[longestIndex], branchModels[longestIndex], siteRateModels[longestIndex], branchRateModels[longestIndex],
-                        null, 
-                        ambiguities[longestIndex], rescalingSchemes[longestIndex], partialsRestrictions.get(longestIndex),
+                        null,
+                        ambiguities[longestIndex], rescalingSchemes[longestIndex], isDelayRescalingUntilUnderflow[longestIndex],
+                        partialsRestrictions.get(longestIndex),
                         xo);
 
-                treeLikelihood.setId(xo.getId() + "_" + instanceCount);
+                treeLikelihood.setId(xo.getId() + "_" + longestIndex + "_" + i);
+                System.err.println(treeLikelihood.getId() + " created.");
                 newList.add(treeLikelihood);
             }
             for (int i = 0; i < newList.size()-1; i++) {
@@ -401,6 +413,7 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
             }
             compound = new TestThreadedCompoundLikelihood(likelihoods);
             //compound = new CompoundLikelihood(likelihoods);
+            //compound = new ThreadedCompoundLikelihood(likelihoods);
             siteCounts[longestIndex] = (instanceCount-1)*siteCounts[longestIndex]/instanceCount;
             longestSize = (instanceCount-1)*longestSize/instanceCount;
 
@@ -541,17 +554,22 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
 
                         BeagleTreeLikelihood treeLikelihood = createTreeLikelihood(
                                 subPatterns, treeModels[longestIndex], branchModels[longestIndex], siteRateModels[longestIndex], branchRateModels[longestIndex],
-                                null, 
-                                ambiguities[longestIndex], rescalingSchemes[longestIndex], partialsRestrictions.get(longestIndex),
+                                null,
+                                ambiguities[longestIndex], rescalingSchemes[longestIndex], isDelayRescalingUntilUnderflow[longestIndex],
+                                partialsRestrictions.get(longestIndex),
                                 xo);
 
-                        treeLikelihood.setId(xo.getId() + "_" + instanceCount);
+                        treeLikelihood.setId(xo.getId() + "_" + longestIndex + "_" + i);
+                        System.err.println(treeLikelihood.getId() + " created.");
                         newList.add(treeLikelihood);
                     }
                     /*for (int i = 0; i < newList.size()+1; i++) {
                         likelihoods.remove(currentLocation[longestIndex]);
                     }*/
                     for (int i = 0; i < newList.size()+timesRetried+1; i++) {
+                        //TEST CODE START
+                        unregisterAllModels((BeagleTreeLikelihood)likelihoods.get(currentLocation[longestIndex]));
+                        //TEST CODE END
                         likelihoods.remove(currentLocation[longestIndex]);
                     }
                     for (int i = 0; i < newList.size(); i++) {
@@ -565,6 +583,7 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
 
                     compound = new TestThreadedCompoundLikelihood(likelihoods);
                     //compound = new CompoundLikelihood(likelihoods);
+                    //compound = new ThreadedCompoundLikelihood(likelihoods);
                     siteCounts[longestIndex] = (instanceCount+timesRetried+1)*siteCounts[longestIndex]/instanceCount;
                     longestSize = (instanceCount+timesRetried+1)*longestSize/instanceCount;
 
@@ -795,10 +814,34 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
 
             }*/
 
+        /*for (int i = 0; i < originalLikelihoods.size(); i++) {
+            ((BeagleTreeLikelihood)originalLikelihoods.get(i)).removeModel(((BeagleTreeLikelihood)originalLikelihoods.get(i)).getBranchModel());
+            ((BeagleTreeLikelihood)originalLikelihoods.get(i)).removeModel(((BeagleTreeLikelihood)originalLikelihoods.get(i)).getBranchRateModel());
+            ((BeagleTreeLikelihood)originalLikelihoods.get(i)).removeModel(((BeagleTreeLikelihood)originalLikelihoods.get(i)).getSiteRateModel());
+            ((BeagleTreeLikelihood)originalLikelihoods.get(i)).removeModel(((BeagleTreeLikelihood)originalLikelihoods.get(i)).getTreeModel());
+            if (((BeagleTreeLikelihood)originalLikelihoods.get(i)).getTipStatesModel() != null) {
+                ((BeagleTreeLikelihood) originalLikelihoods.get(i)).removeModel(((BeagleTreeLikelihood) originalLikelihoods.get(i)).getTipStatesModel());
+            }
+        }*/
+
+        for (int i = 0; i < originalLikelihoods.size(); i++) {
+            unregisterAllModels((BeagleTreeLikelihood)originalLikelihoods.get(i));
+        }
+
         return compound;
 
     }
 
+    private void unregisterAllModels(BeagleTreeLikelihood btl) {
+        btl.removeModel(btl.getTreeModel());
+        btl.removeModel(btl.getBranchRateModel());
+        btl.removeModel(btl.getBranchModel());
+        btl.removeModel(btl.getSiteRateModel());
+        if (btl.getTipStatesModel() != null) {
+            btl.removeModel(btl.getTipStatesModel());
+        }
+    }
+
     //************************************************************************
     // AbstractXMLObjectParser implementation
     //************************************************************************
@@ -812,9 +855,9 @@ public class OptimizedBeagleTreeLikelihoodParser extends AbstractXMLObjectParser
     }
 
     public static final XMLSyntaxRule[] rules = {
-        new ElementRule(BeagleTreeLikelihood.class, 1, Integer.MAX_VALUE),
-        AttributeRule.newIntegerRule(CALIBRATE, true),
-        AttributeRule.newIntegerRule(RETRY, true)
+            new ElementRule(BeagleTreeLikelihood.class, 1, Integer.MAX_VALUE),
+            AttributeRule.newIntegerRule(CALIBRATE, true),
+            AttributeRule.newIntegerRule(RETRY, true)
     };
 
     public XMLSyntaxRule[] getSyntaxRules() {
