@@ -31,6 +31,14 @@ import dr.inference.model.Parameter;
 import dr.inference.model.Variable;
 import dr.math.distributions.GammaDistribution;
 import dr.app.beagle.evomodel.substmodel.SubstitutionModel;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
 
 /**
  * GammaSiteModel - A SiteModel that has a gamma distributed rates across sites.
@@ -39,7 +47,7 @@ import dr.app.beagle.evomodel.substmodel.SubstitutionModel;
  * @version $Id: GammaSiteModel.java,v 1.31 2005/09/26 14:27:38 rambaut Exp $
  */
 
-public class GammaSiteRateModel extends AbstractModel implements SiteRateModel {
+public class GammaSiteRateModel extends AbstractModel implements SiteRateModel, Citable {
 
     public GammaSiteRateModel(String name) {
         this(   name,
@@ -274,6 +282,10 @@ public class GammaSiteRateModel extends AbstractModel implements SiteRateModel {
         ratesKnown = true;
     }
 
+    public boolean hasInvariantSites() {
+        return invarParameter != null;
+    }
+
     // *****************************************************************
     // Interface ModelComponent
     // *****************************************************************
@@ -342,5 +354,32 @@ public class GammaSiteRateModel extends AbstractModel implements SiteRateModel {
         this.substitutionModel = substitutionModel;
     }
 
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Discrete gamma-distributed rate heterogeneity model";
+    }
+
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public final static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("Z", "Yang")
+            },
+            "Maximum likelihood phylogenetic estimation from DNA sequences with variable rates over sites: approximate methods",
+            1994,
+            "J. Mol. Evol.",
+            39,
+            306, 314,
+            Citation.Status.PUBLISHED
+    );
+
     private SubstitutionModel substitutionModel;
 }
\ No newline at end of file
