@@ -33,19 +33,45 @@ import dr.inference.model.Likelihood;
 import dr.inference.model.Model;
 import dr.inference.model.Parameter;
 import dr.math.matrixAlgebra.Vector;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+import dr.util.CommonCitations;
 
-import java.util.Arrays;
+import java.util.*;
 
 /**
  * @author Marc Suchard
  */
-public class ComplexSubstitutionModel extends GeneralSubstitutionModel implements Likelihood {
+public class ComplexSubstitutionModel extends GeneralSubstitutionModel implements Likelihood, Citable {
 
     public ComplexSubstitutionModel(String name, DataType dataType, FrequencyModel freqModel, Parameter parameter) {
         super(name, dataType, freqModel, parameter, -1);
         probability = new double[stateCount * stateCount];
     }
 
+    @Override
+    protected void setupDimensionNames(int relativeTo) {
+        List<String> rateNames = new ArrayList<String>();
+
+        String ratePrefix = ratesParameter.getParameterName();
+
+        for (int i = 0; i < dataType.getStateCount(); ++i) {
+            for (int j = i + 1; j < dataType.getStateCount(); ++j) {
+                rateNames.add(getDimensionString(i, j, ratePrefix));
+            }
+        }
+
+        for (int j = 0; j < dataType.getStateCount(); ++j) {
+            for (int i = j + 1; i < dataType.getStateCount(); ++i) {
+                rateNames.add(getDimensionString(i, j, ratePrefix));
+            }
+        }
+
+        String[] tmp = new String[0];
+        ratesParameter.setDimensionNames(rateNames.toArray(tmp));
+    }
+
     protected EigenSystem getDefaultEigenSystem(int stateCount) {
         return new ComplexColtEigenSystem(stateCount);
     }
@@ -211,6 +237,10 @@ public class ComplexSubstitutionModel extends GeneralSubstitutionModel implement
         System.err.println(new Vector(probability));
     }
 
+    @Override
+    public Set<Likelihood> getLikelihoodSet() {
+        return new HashSet<Likelihood>(Arrays.asList(this));
+    }
 
     @Override
     public boolean isUsed() {
@@ -248,5 +278,20 @@ public class ComplexSubstitutionModel extends GeneralSubstitutionModel implement
         this.doNormalization = normalize;
     }
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Complex-diagonalizable, irreversible substitution model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CommonCitations.EDWARDS_2011_ANCIENT);
+    }
+
     private boolean doNormalization = true;
 }
