@@ -29,6 +29,9 @@ import dr.evolution.datatype.DataType;
 import dr.inference.model.Parameter;
 import dr.inference.model.DuplicatedParameter;
 
+import java.util.ArrayList;
+import java.util.List;
+
 /**
  * <b>A general model of sequence substitution</b>. A general reversible class for any
  * data type.
@@ -66,6 +69,8 @@ public class GeneralSubstitutionModel extends BaseSubstitutionModel {
             if (!(ratesParameter instanceof DuplicatedParameter))
                 ratesParameter.addBounds(new Parameter.DefaultBounds(Double.POSITIVE_INFINITY, 0.0,
                         ratesParameter.getDimension()));
+
+            setupDimensionNames(relativeTo);
         }
         setRatesRelativeTo(relativeTo);
     }
@@ -103,6 +108,35 @@ public class GeneralSubstitutionModel extends BaseSubstitutionModel {
         }
     }
 
+    protected void setupDimensionNames(int relativeTo) {
+        List<String> rateNames = new ArrayList<String>();
+
+        String ratePrefix = ratesParameter.getParameterName();
+
+        int index = 0;
+
+        for (int i = 0; i < dataType.getStateCount(); ++i) {
+            for (int j = i + 1; j < dataType.getStateCount(); ++j) {
+                if (index != relativeTo) {
+                    rateNames.add(getDimensionString(i, j, ratePrefix));
+                }
+            }
+            index++;
+        }
+
+        String[] tmp = new String[0];
+        ratesParameter.setDimensionNames(rateNames.toArray(tmp));
+    }
+
+    protected String getDimensionString(int i, int j, String prefix) {
+        String codes =  dataType.getCode(i) + "." + dataType.getCode(j);
+        if (prefix == null) {
+            return codes;
+        } else {
+            return prefix + "." + codes;
+        }
+    }
+
     /**
      * set which rate the others are relative to
      */
