@@ -27,6 +27,12 @@ package dr.app.beagle.evomodel.substmodel;
 
 import dr.evolution.datatype.Codons;
 import dr.inference.model.Parameter;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.List;
 
 /**
  * Muse-Gaut model of codon evolution
@@ -35,13 +41,13 @@ import dr.inference.model.Parameter;
  * @author Guy Baele
  * @author Philippe lemey
  */
-public class MG94CodonModel extends AbstractCodonModel {
+public class MG94CodonModel extends AbstractCodonModel implements Citable {
 
     protected Parameter alphaParameter;
     protected Parameter betaParameter;
 
-    private final int numSynTransitions;
-    private final int numNonsynTransitions;
+    protected final int numSynTransitions;
+    protected final int numNonsynTransitions;
 
     public MG94CodonModel(Codons codonDataType, Parameter alphaParameter, Parameter betaParameter,
                           FrequencyModel freqModel) {
@@ -80,11 +86,11 @@ public class MG94CodonModel extends AbstractCodonModel {
         return count;
     }
 
-    private int getNumSynTransitions() {
+    protected int getNumSynTransitions() {
         return 2 * countRates(1, 2);
     }
 
-    private int getNumNonsynTransitions() {
+    protected int getNumNonsynTransitions() {
         return 2 * countRates(3, 4);
     }
 
@@ -137,4 +143,30 @@ public class MG94CodonModel extends AbstractCodonModel {
     }
 
     private boolean doNormalization = true;
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Muse-Gaut codon substitution model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("SV", "Muse"),
+                    new Author("BS", "Gaut")
+            },
+            "A likelihood approach for comparing synonymous and nonsynonymous nucleotide substitution rates, with application to the chloroplast genome",
+            1994,
+            "Mol Biol Evol",
+            11, 715, 724
+    );
 }
\ No newline at end of file
