@@ -1,7 +1,7 @@
 /*
  * ProductChainSubstitutionModel.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -34,8 +34,7 @@ import dr.util.Citable;
 import dr.util.Citation;
 import dr.util.CommonCitations;
 
-import java.util.ArrayList;
-import java.util.List;
+import java.util.*;
 import java.util.logging.Logger;
 
 //import dr.math.matrixAlgebra.Vector;
@@ -110,12 +109,18 @@ public class ProductChainSubstitutionModel extends BaseSubstitutionModel impleme
                 + Citable.Utils.getCitationString(this));
     }
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Product chain substitution model";
+    }
+
     public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                CommonCitations.OBRIEN_2009
-        );
-        return citations;
+        return Collections.singletonList(CommonCitations.OBRIEN_2009_LEARNING);
     }
 
     public EigenDecomposition getEigenDecomposition() {
