@@ -1,7 +1,7 @@
 /*
  * SVSGeneralSubstitutionModel.java
  *
- * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2016 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -25,17 +25,22 @@
 
 package dr.app.beagle.evomodel.substmodel;
 
-import dr.inference.model.*;
+import dr.evolution.datatype.DataType;
 import dr.inference.loggers.LogColumn;
 import dr.inference.loggers.NumberColumn;
-import dr.evolution.datatype.DataType;
+import dr.inference.model.*;
+import dr.util.Citable;
+import dr.util.Citation;
+import dr.util.CommonCitations;
+
+import java.util.*;
 
 /**
  * @author Marc Suchard
  */
 
 public class SVSGeneralSubstitutionModel extends GeneralSubstitutionModel implements Likelihood,
-        BayesianStochasticSearchVariableSelection {
+        BayesianStochasticSearchVariableSelection, Citable {
 
     public SVSGeneralSubstitutionModel(String name, DataType dataType, FrequencyModel freqModel,
                                        Parameter ratesParameter, Parameter indicatorsParameter) {
@@ -48,6 +53,7 @@ public class SVSGeneralSubstitutionModel extends GeneralSubstitutionModel implem
             addVariable(indicatorsParameter);
         }
 
+        setupIndicatorDimensionNames(-1);
     }
 
     @Override
@@ -57,12 +63,27 @@ public class SVSGeneralSubstitutionModel extends GeneralSubstitutionModel implem
         }
     }
 
+    protected void setupIndicatorDimensionNames(int relativeTo) {
+        List<String> indicatorNames = new ArrayList<String>();
+
+        String indicatorPrefix = indicatorsParameter.getParameterName();
+
+        for (int i = 0; i < dataType.getStateCount(); ++i) {
+            for (int j = i + 1; j < dataType.getStateCount(); ++j) {
+                indicatorNames.add(getDimensionString(i, j, indicatorPrefix));
+            }
+        }
+
+        String[] tmp = new String[0];
+        indicatorsParameter.setDimensionNames(indicatorNames.toArray(tmp));
+    }
+
     public Parameter getIndicators() {
         return indicatorsParameter;
     }
 
     public boolean validState() {
-        return !updateMatrix || Utils.connectedAndWellConditioned(probability,this);
+        return !updateMatrix || BayesianStochasticSearchVariableSelection.Utils.connectedAndWellConditioned(probability,this);
     }
 
     protected void handleVariableChangedEvent(Variable variable, int index, Parameter.ChangeType type) {
@@ -87,7 +108,7 @@ public class SVSGeneralSubstitutionModel extends GeneralSubstitutionModel implem
      */
     public double getLogLikelihood() {
         if (updateMatrix) {
-            if (!Utils.connectedAndWellConditioned(probability,this)) {
+            if (!BayesianStochasticSearchVariableSelection.Utils.connectedAndWellConditioned(probability,this)) {
                 return Double.NEGATIVE_INFINITY;
             }
         }
@@ -116,6 +137,11 @@ public class SVSGeneralSubstitutionModel extends GeneralSubstitutionModel implem
         return "SVSGeneralSubstitutionModel-connectedness";
     }
 
+    @Override
+    public Set<Likelihood> getLikelihoodSet() {
+        return new HashSet<Likelihood>(Arrays.asList(this));
+    }
+
     @Override
     public boolean isUsed() {
         return super.isUsed() && isUsed;
@@ -137,6 +163,21 @@ public class SVSGeneralSubstitutionModel extends GeneralSubstitutionModel implem
         };
     }
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Stochastic search variable selection, reversible substitution model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CommonCitations.LEMEY_2009_BAYESIAN);
+    }
+
     protected class LikelihoodColumn extends NumberColumn {
         public LikelihoodColumn(String label) {
             super(label);
