@@ -1,7 +1,7 @@
 /*
  * BeastMain.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -44,6 +44,7 @@ import jam.util.IconUtils;
 
 import javax.swing.*;
 import java.io.File;
+import java.io.FileOutputStream;
 import java.io.FileReader;
 import java.io.IOException;
 import java.util.*;
@@ -124,6 +125,12 @@ public class BeastMain {
             });
             infoLogger.addHandler(errorHandler);
 
+            if (System.getProperty("citations.filename") != null) {
+                FileOutputStream citationStream = new FileOutputStream(System.getProperty("citations.filename"));
+                Handler citationHandler = new MessageLogHandler(citationStream);
+                Logger.getLogger("dr.apps.beast").addHandler(citationHandler);
+            }
+
             logger.setUseParentHandlers(false);
 
             infoLogger.info("Parsing XML file: " + fileName);
@@ -237,7 +244,7 @@ public class BeastMain {
                 infoLogger.severe("Error running file: " + fileName);
                 infoLogger.severe(
                         "The initial model is invalid because state has a zero probability.\n\n" +
-                                "If the log likelihood of the tree is -Inf, his may be because the\n" +
+                                "If the log likelihood of the tree is -Inf, this may be because the\n" +
                                 "initial, random tree is so large that it has an extremely bad\n" +
                                 "likelihood which is being rounded to zero.\n\n" +
                                 "Alternatively, it may be that the product of starting mutation rate\n" +
@@ -323,7 +330,7 @@ public class BeastMain {
                         new Arguments.IntegerOption("errors", "Specify maximum number of numerical errors before stopping"),
                         new Arguments.IntegerOption("threads", "The number of computational threads to use (default auto)"),
                         new Arguments.Option("java", "Use Java only, no native implementations"),
-                        new Arguments.RealOption("threshold", 0.0, Double.MAX_VALUE, "Full evaluation test threshold (default 1E-6)"),
+                        new Arguments.RealOption("threshold", 0.0, Double.MAX_VALUE, "Full evaluation test threshold (default 0.1)"),
 
                         new Arguments.Option("beagle_off", "Don't use the BEAGLE library"),
                         new Arguments.Option("beagle", "Use BEAGLE library if available (default on)"),
@@ -341,13 +348,20 @@ public class BeastMain {
                         new Arguments.Option("beagle_async", "BEAGLE: use asynchronous kernels if available"),
                         new Arguments.StringOption("beagle_scaling", new String[]{"default", "dynamic", "delayed", "always", "none"},
                                 false, "BEAGLE: specify scaling scheme to use"),
-                        new Arguments.IntegerOption("beagle_rescale", "BEAGLE: frequency of rescaling (dynamic scaling only)"),
+                        new Arguments.Option("beagle_delay_scaling_off", "BEAGLE: don't wait until underflow for scaling option"),
+                        new Arguments.LongOption("beagle_rescale", "BEAGLE: frequency of rescaling (dynamic scaling only)"),
                         new Arguments.Option("mpi", "Use MPI rank to label output"),
 
                         new Arguments.IntegerOption("mc3_chains", 1, Integer.MAX_VALUE, "number of chains"),
                         new Arguments.RealOption("mc3_delta", 0.0, Double.MAX_VALUE, "temperature increment parameter"),
                         new Arguments.RealArrayOption("mc3_temperatures", -1, "a comma-separated list of the hot chain temperatures"),
-                        new Arguments.IntegerOption("mc3_swap", 1, Integer.MAX_VALUE, "frequency at which chains temperatures will be swapped"),
+                        new Arguments.LongOption("mc3_swap", 1, Integer.MAX_VALUE, "frequency at which chains temperatures will be swapped"),
+
+                        new Arguments.StringOption("load_dump", "FILENAME", "Specify a filename to load a dumped state from"),
+                        new Arguments.LongOption("dump_state", "Specify a state at which to write a dump file"),
+                        new Arguments.LongOption("dump_every", "Specify a frequency to write a dump file"),
+
+                        new Arguments.StringOption("citations_file", "FILENAME", "Specify a filename to write a citation list to"),
 
                         new Arguments.Option("version", "Print the version and credits and stop"),
                         new Arguments.Option("help", "Print this information and stop"),
@@ -355,6 +369,15 @@ public class BeastMain {
 
         int argumentCount = 0;
 
+        StringBuilder commandLine = new StringBuilder();
+        for (int i = 0; i < args.length; i++) {
+            if (i > 0) {
+                commandLine.append(" ");
+            }
+            commandLine.append(args[i]);
+        }
+        System.setProperty("command_line", commandLine.toString());
+
         try {
             argumentCount = arguments.parseArguments(args);
         } catch (Arguments.ArgumentException ae) {
@@ -470,11 +493,13 @@ public class BeastMain {
         if (!arguments.hasOption("beagle_SSE_off")) {
             beagleFlags |= BeagleFlag.VECTOR_SSE.getMask();
         }
-        if (arguments.hasOption("beagle_double")) {
-            beagleFlags |= BeagleFlag.PRECISION_DOUBLE.getMask();
-        }
+//        if (arguments.hasOption("beagle_double")) {
+//            beagleFlags |= BeagleFlag.PRECISION_DOUBLE.getMask();
+//        }
         if (arguments.hasOption("beagle_single")) {
             beagleFlags |= BeagleFlag.PRECISION_SINGLE.getMask();
+        } else {
+            beagleFlags |= BeagleFlag.PRECISION_DOUBLE.getMask();
         }
         if (arguments.hasOption("beagle_async")) {
             beagleFlags |= BeagleFlag.COMPUTATION_ASYNCH.getMask();
@@ -492,8 +517,12 @@ public class BeastMain {
             System.setProperty("beagle.scaling", arguments.getStringOption("beagle_scaling"));
         }
 
+        if (arguments.hasOption("beagle_delay_scaling_off")) {
+            System.setProperty("beagle.delay.scaling", Boolean.FALSE.toString());
+        }
+
         if (arguments.hasOption("beagle_rescale")) {
-            System.setProperty("beagle.rescale", Integer.toString(arguments.getIntegerOption("beagle_rescale")));
+            System.setProperty("beagle.rescale", Long.toString(arguments.getLongOption("beagle_rescale")));
         }
 
         // ============= Other settings =============
@@ -516,6 +545,26 @@ public class BeastMain {
             }
         }
 
+        if (arguments.hasOption("load_dump")) {
+            String debugStateFile = arguments.getStringOption("load_dump");
+            System.setProperty(MCMC.LOAD_DUMP_FILE, debugStateFile);
+        }
+
+        if (arguments.hasOption("dump_state")) {
+            long debugWriteState = arguments.getLongOption("dump_state");
+            System.setProperty(MCMC.DUMP_STATE, Long.toString(debugWriteState));
+        }
+
+        if (arguments.hasOption("dump_every")) {
+            long debugWriteEvery = arguments.getLongOption("dump_every");
+            System.setProperty(MCMC.DUMP_EVERY, Long.toString(debugWriteEvery));
+        }
+
+        if (arguments.hasOption("citations_file")) {
+            String debugStateFile = arguments.getStringOption("citations_file");
+            System.setProperty("citations.filename", debugStateFile);
+        }
+
         if (useMPI) {
             String[] nullArgs = new String[0];
             try {
@@ -621,6 +670,8 @@ public class BeastMain {
                 }
                 if (dialog.preferBeagleSSE()) {
                     beagleFlags |= BeagleFlag.VECTOR_SSE.getMask();
+                } else {
+                    beagleFlags &= ~BeagleFlag.VECTOR_SSE.getMask();
                 }
                 if (dialog.preferBeagleGPU()) {
                     beagleFlags |= BeagleFlag.PROCESSOR_GPU.getMask();
@@ -647,7 +698,7 @@ public class BeastMain {
 
             if (BeagleInfo.getVersion().startsWith("1.")) {
                 System.err.println("WARNING: You are currenly using BEAGLE v1.x. For best performance and compatibility\n" +
-                        "with models in BEAST, please upgrade to BEAGLE v2.x at http://beagle-lib.googlecode.com/\n");
+                        "with models in BEAST, please upgrade to BEAGLE v2.x at http://github.com/beagle-dev/beagle-lib/\n");
             }
         }
 
