@@ -25,8 +25,14 @@
 
 package dr.app.beast;
 
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
 import dr.util.Version;
 
+import java.util.Collections;
+import java.util.List;
+
 /**
  * This class provides a mechanism for returning the version number of the
  * dr software.
@@ -39,20 +45,22 @@ import dr.util.Version;
  *
  * $Id$
  */
-public class BeastVersion implements Version {
+public class BeastVersion implements Version, Citable {
+
+    public static final BeastVersion INSTANCE = new BeastVersion();
 
     /**
      * Version string: assumed to be in format x.x.x
      */
-    private static final String VERSION = "1.8.3";
+    private static final String VERSION = "1.8.4";
 
-    private static final String DATE_STRING = "2002-2015";
+    private static final String DATE_STRING = "2002-2016";
 
-    private static final boolean IS_PRERELEASE = true;
+    private static final boolean IS_PRERELEASE = false;
 
     // this is now being manually updated since the move to GitHub. Using date in yyyymmdd format (suffix
     // with b,c,d etc if multiple revisions in a day.
-    private static final String REVISION = "GitHub 20150808";
+    private static final String REVISION = "GitHub 20160615";
 
     public String getVersion() {
         return VERSION;
@@ -128,4 +136,33 @@ public class BeastVersion implements Version {
             return "Invalid Revision String : " + REVISION;
         }
     }
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.FRAMEWORK;
+    }
+
+    @Override
+    public String getDescription() {
+        return "BEAST primary citation";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("AJ", "Drummond"),
+                    new Author("MA", "Suchard"),
+                    new Author("Dong", "Xie"),
+                    new Author("A", "Rambaut")
+            },
+            "Bayesian phylogenetics with BEAUti and the BEAST 1.7",
+            2012,
+            "Mol Biol Evol",
+            29, 1969, 1973,
+            "10.1093/molbev/mss075");
+
 }
