@@ -28,8 +28,6 @@ package dr.app.beauti.generator;
 import dr.app.beauti.components.ComponentFactory;
 import dr.app.beauti.options.*;
 import dr.app.beauti.types.ClockType;
-import dr.app.beauti.types.FixRateType;
-import dr.app.beauti.types.RelativeRatesType;
 import dr.app.beauti.types.TreePriorType;
 import dr.app.beauti.util.XMLWriter;
 import dr.evolution.datatype.DataType;
@@ -46,8 +44,8 @@ import dr.evomodelxml.speciation.SpeciesTreeModelParser;
 import dr.evomodelxml.speciation.YuleModelParser;
 import dr.evomodelxml.substmodel.GeneralSubstitutionModelParser;
 import dr.inference.model.ParameterParser;
+import dr.inference.operators.OperatorSchedule;
 import dr.inference.operators.RateBitExchangeOperator;
-import dr.inference.operators.SimpleOperatorSchedule;
 import dr.inferencexml.model.CompoundParameterParser;
 import dr.inferencexml.operators.*;
 import dr.util.Attribute;
@@ -95,7 +93,9 @@ public class OperatorsGenerator extends Generator {
         operatorAttributes = new Attribute[] {
                 new Attribute.Default<String>(XMLParser.ID, "operators"),
                 new Attribute.Default<String>(SimpleOperatorScheduleParser.OPTIMIZATION_SCHEDULE,
-                        (shouldLogCool ? SimpleOperatorSchedule.LOG_STRING : SimpleOperatorSchedule.DEFAULT_STRING))
+                        (shouldLogCool ?
+                                OperatorSchedule.OptimizationTransform.LOG.toString() :
+                                OperatorSchedule.OptimizationTransform.DEFAULT.toString()))
         };
 
         writer.writeComment("Define operators");
@@ -106,7 +106,7 @@ public class OperatorsGenerator extends Generator {
         );
 
         for (Operator operator : operators) {
-            if (operator.weight > 0. && operator.inUse) {
+            if (operator.getWeight() > 0. && operator.isUsed()) {
                 setModelPrefix(operator.getPrefix());
 
                 writeOperator(operator, writer);
@@ -120,7 +120,7 @@ public class OperatorsGenerator extends Generator {
 
     private void writeOperator(Operator operator, XMLWriter writer) {
 
-        switch (operator.operatorType) {
+        switch (operator.getOperatorType()) {
 
             case SCALE:
                 writeScaleOperator(operator, writer);
@@ -185,6 +185,9 @@ public class OperatorsGenerator extends Generator {
             case INTEGER_UNIFORM:
                 writeIntegerUniformOperator(operator, writer);
                 break;
+            case SUBTREE_LEAP:
+                writeSubtreeLeapOperator(operator, writer);
+                break;
             case SUBTREE_SLIDE:
                 writeSubtreeSlideOperator(operator, writer);
                 break;
@@ -218,11 +221,11 @@ public class OperatorsGenerator extends Generator {
     }
 
     private void writeParameter1Ref(XMLWriter writer, Operator operator) {
-        writer.writeIDref(ParameterParser.PARAMETER, operator.parameter1.getName());
+        writer.writeIDref(ParameterParser.PARAMETER, operator.getParameter1().getName());
     }
 
     private void writeParameter2Ref(XMLWriter writer, Operator operator) {
-        writer.writeIDref(ParameterParser.PARAMETER, operator.parameter2.getName());
+        writer.writeIDref(ParameterParser.PARAMETER, operator.getParameter2().getName());
     }
 
     private void writeOperatorRef(XMLWriter writer, Operator operator) {
@@ -233,8 +236,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 ScaleOperatorParser.SCALE_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 });
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
@@ -245,8 +248,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 ScaleOperatorParser.SCALE_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight),
+                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight()),
                         new Attribute.Default<String>(ScaleOperatorParser.SCALE_ALL_IND, indepedently ? "true" : "false")
                 });
         writeParameter1Ref(writer, operator);
@@ -259,8 +262,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 name,
                 new Attribute[]{
-                        new Attribute.Default<Double>("windowSize", operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>("windowSize", operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 });
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
@@ -272,10 +275,13 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 name,
                 new Attribute[]{
-                        new Attribute.Default<Double>("windowSize", operator.tuning),
-                        getWeightAttribute(operator.weight),
+                        new Attribute.Default<Double>("windowSize", operator.getTuning()),
+                        getWeightAttribute(operator.getWeight()),
                         new Attribute.Default<String>("boundaryCondition",
-                                (reflecting ? "reflecting" : "absorbing"))
+                                (reflecting ? "reflecting" : "absorbing")),
+                        (operator.isAutoOptimize() == false ?
+                                new Attribute.Default<Boolean>("autoOptimize", false) :
+                                null)
                 });
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
@@ -287,8 +293,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 name,
                 new Attribute[]{
-                        new Attribute.Default<Double>("windowSize", operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>("windowSize", operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 });
         writeParameter1Ref(writer, operator);
         writer.writeCloseTag(name);
@@ -296,14 +302,14 @@ public class OperatorsGenerator extends Generator {
 
     private void writeIntegerRandomWalkOperator(Operator operator, XMLWriter writer) {
 
-        int windowSize = (int) Math.round(operator.tuning);
+        int windowSize = (int) Math.round(operator.getTuning());
         if (windowSize < 1) windowSize = 1;
         final String name = RandomWalkIntegerOperatorParser.RANDOM_WALK_INTEGER_OPERATOR;
         writer.writeOpenTag(
                 name,
                 new Attribute[]{
                         new Attribute.Default<Integer>("windowSize", windowSize),
-                        getWeightAttribute(operator.weight)
+                        getWeightAttribute(operator.getWeight())
                 });
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
@@ -314,17 +320,17 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 ScaleOperatorParser.SCALE_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
+                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
                         new Attribute.Default<String>(ScaleOperatorParser.SCALE_ALL, "true"),
-                        getWeightAttribute(operator.weight)
+                        getWeightAttribute(operator.getWeight())
                 });
 
-        if (operator.parameter2 == null) {
+        if (operator.getParameter2() == null) {
             writeParameter1Ref(writer, operator);
         } else {
             writer.writeOpenTag(CompoundParameterParser.COMPOUND_PARAMETER);
             writeParameter1Ref(writer, operator);
-//            writer.writeIDref(ParameterParser.PARAMETER, operator.parameter2.getName());
+//            writer.writeIDref(ParameterParser.PARAMETER, operator.getParameter2().getName());
             writeParameter2Ref(writer, operator);
             writer.writeCloseTag(CompoundParameterParser.COMPOUND_PARAMETER);
         }
@@ -335,8 +341,8 @@ public class OperatorsGenerator extends Generator {
     private void writeCenteredOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(CenteredScaleOperatorParser.CENTERED_SCALE,
                 new Attribute[]{
-                        new Attribute.Default<Double>(CenteredScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(CenteredScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 }
         );
         writeParameter1Ref(writer, operator);
@@ -346,51 +352,28 @@ public class OperatorsGenerator extends Generator {
 
     private void writeDeltaOperator(Operator operator, XMLWriter writer) {
 
-        if (operator.getBaseName().startsWith(RelativeRatesType.MU_RELATIVE_RATES.toString())) {
+        int[] parameterWeights = operator.getParameter1().getParameterDimensionWeights();
+        Attribute[] attributes;
 
-            int[] parameterWeights = ((PartitionSubstitutionModel) operator.parameter1.getOptions()).getPartitionCodonWeights();
-
-            if (parameterWeights != null && parameterWeights.length > 1) {
-                String pw = "" + parameterWeights[0];
-                for (int i = 1; i < parameterWeights.length; i++) {
-                    pw += " " + parameterWeights[i];
-                }
-                writer.writeOpenTag(DeltaExchangeOperatorParser.DELTA_EXCHANGE,
-                        new Attribute[]{
-                                new Attribute.Default<Double>(DeltaExchangeOperatorParser.DELTA, operator.tuning),
-                                new Attribute.Default<String>(DeltaExchangeOperatorParser.PARAMETER_WEIGHTS, pw),
-                                getWeightAttribute(operator.weight)
-                        }
-                );
-            }
-
-        } else if (operator.getBaseName().startsWith(RelativeRatesType.CLOCK_RELATIVE_RATES.toString())) {
-
-            int[] parameterWeights = options.clockModelOptions.getPartitionClockWeights(operator.getClockModelGroup());
-
-            if (parameterWeights != null && parameterWeights.length > 1) {
-                String pw = "" + parameterWeights[0];
-                for (int i = 1; i < parameterWeights.length; i++) {
-                    pw += " " + parameterWeights[i];
-                }
-                writer.writeOpenTag(DeltaExchangeOperatorParser.DELTA_EXCHANGE,
-                        new Attribute[]{
-                                new Attribute.Default<Double>(DeltaExchangeOperatorParser.DELTA, operator.tuning),
-                                new Attribute.Default<String>(DeltaExchangeOperatorParser.PARAMETER_WEIGHTS, pw),
-                                getWeightAttribute(operator.weight)
-                        }
-                );
+        if (parameterWeights != null && parameterWeights.length > 1) {
+            String pw = "" + parameterWeights[0];
+            for (int i = 1; i < parameterWeights.length; i++) {
+                pw += " " + parameterWeights[i];
             }
+            attributes = new Attribute[]{
+                    new Attribute.Default<Double>(DeltaExchangeOperatorParser.DELTA, operator.getTuning()),
+                    new Attribute.Default<String>(DeltaExchangeOperatorParser.PARAMETER_WEIGHTS, pw),
+                    getWeightAttribute(operator.getWeight())
+            };
 
         } else {
-            writer.writeOpenTag(DeltaExchangeOperatorParser.DELTA_EXCHANGE,
-                    new Attribute[]{
-                            new Attribute.Default<Double>(DeltaExchangeOperatorParser.DELTA, operator.tuning),
-                            getWeightAttribute(operator.weight)
-                    }
-            );
+            attributes = new Attribute[]{
+                    new Attribute.Default<Double>(DeltaExchangeOperatorParser.DELTA, operator.getTuning()),
+                    getWeightAttribute(operator.getWeight())
+            };
         }
 
+        writer.writeOpenTag(DeltaExchangeOperatorParser.DELTA_EXCHANGE, attributes);
         writeParameter1Ref(writer, operator);
         writer.writeCloseTag(DeltaExchangeOperatorParser.DELTA_EXCHANGE);
     }
@@ -398,9 +381,9 @@ public class OperatorsGenerator extends Generator {
     private void writeIntegerDeltaOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(DeltaExchangeOperatorParser.DELTA_EXCHANGE,
                 new Attribute[]{
-                        new Attribute.Default<String>(DeltaExchangeOperatorParser.DELTA, Integer.toString((int) operator.tuning)),
+                        new Attribute.Default<String>(DeltaExchangeOperatorParser.DELTA, Integer.toString((int) operator.getTuning())),
                         new Attribute.Default<String>("integer", "true"),
-                        getWeightAttribute(operator.weight),
+                        getWeightAttribute(operator.getWeight()),
                         new Attribute.Default<String>("autoOptimize", "false")
                 }
         );
@@ -412,8 +395,8 @@ public class OperatorsGenerator extends Generator {
     private void writeSwapOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(SwapOperatorParser.SWAP_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<String>("size", Integer.toString((int) operator.tuning)),
-                        getWeightAttribute(operator.weight),
+                        new Attribute.Default<String>("size", Integer.toString((int) operator.getTuning())),
+                        getWeightAttribute(operator.getWeight()),
                         new Attribute.Default<String>("autoOptimize", "false")
                 }
         );
@@ -424,7 +407,7 @@ public class OperatorsGenerator extends Generator {
 
     private void writeBitFlipOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(BitFlipOperatorParser.BIT_FLIP_OPERATOR,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
         writer.writeCloseTag(BitFlipOperatorParser.BIT_FLIP_OPERATOR);
@@ -432,8 +415,8 @@ public class OperatorsGenerator extends Generator {
 
     private void writeBitFlipInSubstOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(BitFlipInSubstitutionModelOperator.BIT_FLIP_OPERATOR, new Attribute[]{
-                new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                getWeightAttribute(operator.weight)});
+                new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                getWeightAttribute(operator.getWeight())});
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
         PartitionSubstitutionModel model = (PartitionSubstitutionModel) operator.getOptions();
@@ -444,7 +427,7 @@ public class OperatorsGenerator extends Generator {
 
     private void writeRateBitExchangeOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(RateBitExchangeOperator.OPERATOR_NAME,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
 
         writer.writeOpenTag(RateBitExchangeOperator.BITS);
         writeParameter1Ref(writer, operator);
@@ -459,14 +442,14 @@ public class OperatorsGenerator extends Generator {
 
     private void writeTreeBitMoveOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(TreeBitMoveOperatorParser.BIT_MOVE_OPERATOR,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writer.writeIDref(TreeModel.TREE_MODEL, modelPrefix + TreeModel.TREE_MODEL);
         writer.writeCloseTag(TreeBitMoveOperatorParser.BIT_MOVE_OPERATOR);
     }
 
     private void writeUniformOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag("uniformOperator",
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
         writer.writeCloseTag("uniformOperator");
@@ -474,7 +457,7 @@ public class OperatorsGenerator extends Generator {
 
     private void writeIntegerUniformOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(UniformIntegerOperatorParser.UNIFORM_INTEGER_OPERATOR,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writeParameter1Ref(writer, operator);
 //        writeOperatorRef(writer, operator);
         writer.writeCloseTag(UniformIntegerOperatorParser.UNIFORM_INTEGER_OPERATOR);
@@ -482,21 +465,21 @@ public class OperatorsGenerator extends Generator {
 
     private void writeNarrowExchangeOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(ExchangeOperatorParser.NARROW_EXCHANGE,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writer.writeIDref(TreeModel.TREE_MODEL, modelPrefix + TreeModel.TREE_MODEL);
         writer.writeCloseTag(ExchangeOperatorParser.NARROW_EXCHANGE);
     }
 
     private void writeWideExchangeOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(ExchangeOperatorParser.WIDE_EXCHANGE,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writer.writeIDref(TreeModel.TREE_MODEL, modelPrefix + TreeModel.TREE_MODEL);
         writer.writeCloseTag(ExchangeOperatorParser.WIDE_EXCHANGE);
     }
 
     private void writeWilsonBaldingOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(WilsonBaldingParser.WILSON_BALDING,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
         writer.writeIDref(TreeModel.TREE_MODEL, modelPrefix + TreeModel.TREE_MODEL);
         // not supported anymore. probably never worked. (todo) get it out of GUI too
 //        if (options.nodeHeightPrior == TreePriorType.CONSTANT) {
@@ -507,7 +490,7 @@ public class OperatorsGenerator extends Generator {
 
     private void writeSampleNonActiveOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(SampleNonActiveGibbsOperatorParser.SAMPLE_NONACTIVE_GIBBS_OPERATOR,
-                getWeightAttribute(operator.weight));
+                getWeightAttribute(operator.getWeight()));
 
         writer.writeOpenTag(SampleNonActiveGibbsOperatorParser.DISTRIBUTION);
         writeOperatorRef(writer, operator);
@@ -528,8 +511,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 GMRFSkyrideBlockUpdateOperatorParser.GRID_BLOCK_UPDATE_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(GMRFSkyrideBlockUpdateOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(GMRFSkyrideBlockUpdateOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 }
         );
         writer.writeIDref(GMRFSkyrideLikelihoodParser.SKYLINE_LIKELIHOOD, modelPrefix + "skygrid");
@@ -540,8 +523,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 GMRFSkyrideBlockUpdateOperatorParser.BLOCK_UPDATE_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(GMRFSkyrideBlockUpdateOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(GMRFSkyrideBlockUpdateOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 }
         );
         writer.writeIDref(GMRFSkyrideLikelihoodParser.SKYLINE_LIKELIHOOD, modelPrefix + "skyride");
@@ -552,8 +535,8 @@ public class OperatorsGenerator extends Generator {
         writer.writeOpenTag(
                 ScaleOperatorParser.SCALE_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 });
         writeParameter1Ref(writer, operator);
         writer.writeOpenTag(ScaleOperatorParser.INDICATORS, new Attribute.Default<String>(ScaleOperatorParser.PICKONEPROB, "1.0"));
@@ -562,12 +545,23 @@ public class OperatorsGenerator extends Generator {
         writer.writeCloseTag(ScaleOperatorParser.SCALE_OPERATOR);
     }
 
+    private void writeSubtreeLeapOperator(Operator operator, XMLWriter writer) {
+        writer.writeOpenTag(SubtreeLeapOperatorParser.SUBTREE_LEAP,
+                new Attribute[]{
+                        new Attribute.Default<Double>("size", operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
+                }
+        );
+        writer.writeIDref(TreeModel.TREE_MODEL, modelPrefix + TreeModel.TREE_MODEL);
+        writer.writeCloseTag(SubtreeLeapOperatorParser.SUBTREE_LEAP);
+    }
+
     private void writeSubtreeSlideOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(SubtreeSlideOperatorParser.SUBTREE_SLIDE,
                 new Attribute[]{
-                        new Attribute.Default<Double>("size", operator.tuning),
+                        new Attribute.Default<Double>("size", operator.getTuning()),
                         new Attribute.Default<String>("gaussian", "true"),
-                        getWeightAttribute(operator.weight)
+                        getWeightAttribute(operator.getWeight())
                 }
         );
         writer.writeIDref(TreeModel.TREE_MODEL, modelPrefix + TreeModel.TREE_MODEL);
@@ -576,7 +570,7 @@ public class OperatorsGenerator extends Generator {
 
     private void writeSpeciesTreeOperator(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(TreeNodeSlideParser.TREE_NODE_REHEIGHT,
-                new Attribute[]{getWeightAttribute(operator.weight)}
+                new Attribute[]{getWeightAttribute(operator.getWeight())}
         );
         writer.writeIDref(TraitData.TRAIT_SPECIES, TraitData.TRAIT_SPECIES);
         writer.writeIDref(SpeciesTreeModelParser.SPECIES_TREE, Generator.SP_TREE);
@@ -586,24 +580,25 @@ public class OperatorsGenerator extends Generator {
     private void writeUpDownOperator(String opTag, Operator operator, XMLWriter writer) {
         writer.writeOpenTag(opTag,
                 new Attribute[]{
-                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 }
         );
 
         writer.writeOpenTag(UpDownOperatorParser.UP);
-        // for isEstimatedRate() = false, write nothing on up part of upDownOp
-        if (!operator.parameter1.isFixed && operator.getClockModelGroup().getRateTypeOption() != FixRateType.FIX_MEAN) {
+
+        if (!operator.getParameter1().isFixed() /* && operator.getClockModelGroup().getRateTypeOption() != FixRateType.FIXED_MEAN */) {
             writeParameter1Ref(writer, operator);
+        } else {
+            writer.writeComment("Rate is fixed - scale node heights only");
         }
         writer.writeCloseTag(UpDownOperatorParser.UP);
 
         writer.writeOpenTag(UpDownOperatorParser.DOWN);
-        if (operator.tag == null) {
-//	        writer.writeIDref(ParameterParser.PARAMETER,  operator.parameter2.getName());
+        if (operator.getTag() == null) {
             writeParameter2Ref(writer, operator);
         } else {
-            writer.writeIDref(operator.tag, operator.idref);
+            writer.writeIDref(operator.getTag(), operator.getIdref());
         }
         writer.writeCloseTag(UpDownOperatorParser.DOWN);
 
@@ -613,45 +608,44 @@ public class OperatorsGenerator extends Generator {
     private void writeUpDownOperatorAllRatesTrees(Operator operator, XMLWriter writer) {
         writer.writeOpenTag(UpDownOperatorParser.UP_DOWN_OPERATOR,
                 new Attribute[]{
-                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.tuning),
-                        getWeightAttribute(operator.weight)
+                        new Attribute.Default<Double>(ScaleOperatorParser.SCALE_FACTOR, operator.getTuning()),
+                        getWeightAttribute(operator.getWeight())
                 }
         );
 
         writer.writeOpenTag(UpDownOperatorParser.UP);
 
         for (PartitionClockModel model : options.getPartitionClockModels()) {
-            if (model.isEstimatedRate()) {
-                switch (model.getClockType()) {
-                    case STRICT_CLOCK:
-                    case RANDOM_LOCAL_CLOCK:
-                        writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + "clock.rate");
-                        break;
+//            if (model.isEstimatedRate()) {
+            switch (model.getClockType()) {
+                case STRICT_CLOCK:
+                case RANDOM_LOCAL_CLOCK:
+                    writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + "clock.rate");
+                    break;
 
-                    case UNCORRELATED:
-                        switch (model.getClockDistributionType()) {
-                            case LOGNORMAL:
-                                writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + ClockType.UCLD_MEAN);
-                                break;
-                            case GAMMA:
-                                throw new UnsupportedOperationException("Uncorrelated gamma relaxed clock model not implemented yet");
+                case UNCORRELATED:
+                    switch (model.getClockDistributionType()) {
+                        case LOGNORMAL:
+                            writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + ClockType.UCLD_MEAN);
+                            break;
+                        case GAMMA:
+                            throw new UnsupportedOperationException("Uncorrelated gamma relaxed clock model not implemented yet");
 //                            break;
-                            case CAUCHY:
-                                throw new UnsupportedOperationException("Uncorrelated Cauchy relaxed clock model not implemented yet");
+                        case CAUCHY:
+                            throw new UnsupportedOperationException("Uncorrelated Cauchy relaxed clock model not implemented yet");
 //                            break;
-                            case EXPONENTIAL:
-                                writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + ClockType.UCED_MEAN);
-                                break;
-                        }
-                        break;
+                        case EXPONENTIAL:
+                            writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + ClockType.UCED_MEAN);
+                            break;
+                    }
+                    break;
 
-                    case AUTOCORRELATED:
-                        throw new UnsupportedOperationException("Autocorrelated relaxed clock model not implemented yet");
+                case AUTOCORRELATED:
+                    throw new UnsupportedOperationException("Autocorrelated relaxed clock model not implemented yet");
 //	                break;
 
-                    default:
-                        throw new IllegalArgumentException("Unknown clock model");
-                }
+                default:
+                    throw new IllegalArgumentException("Unknown clock model");
             }
         }
         if (options.useStarBEAST) {
