@@ -1,7 +1,7 @@
 /*
  * SubstitutionModelGenerator.java
  *
- * Copyright (c) 2002-2011 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -112,8 +112,6 @@ public class SubstitutionModelGenerator extends Generator {
                     writer.writeCloseTag(HKYParser.KAPPA);
                     writer.writeCloseTag(NucModelType.HKY.getXMLName());
 
-                    throw new IllegalArgumentException("AR: Need to check that kappa = 1 for JC (I have feeling it should be 0.5)");
-
                 } else {
                     // Hasegawa Kishino and Yano 85 model
                     if (model.getNucSubstitutionModel() == NucModelType.HKY) {
@@ -447,42 +445,6 @@ public class SubstitutionModelGenerator extends Generator {
         writer.writeCloseTag(FrequencyModelParser.FREQUENCIES);
     }
 
-    /**
-     * Write the allMus for each partition model.
-     *
-     * @param model  PartitionSubstitutionModel
-     * @param writer XMLWriter
-     */
-    public void writeAllMus(PartitionSubstitutionModel model, XMLWriter writer) {
-        if (model.hasCodon()) { // write allMus for codon model
-            // allMus is global for each gene
-            writer.writeOpenTag(CompoundParameterParser.COMPOUND_PARAMETER,
-                    new Attribute[]{new Attribute.Default<String>(XMLParser.ID, model.getPrefix() + "allMus")});
-
-            writeMuParameterRefs(model, writer);
-
-            writer.writeCloseTag(CompoundParameterParser.COMPOUND_PARAMETER);
-        }
-    }
-
-    /**
-     * Write the all the mu parameters for this partition model.
-     *
-     * @param writer the writer
-     * @param model  the partition model to write in BEAST XML
-     */
-    public void writeMuParameterRefs(PartitionSubstitutionModel model, XMLWriter writer) {
-
-        if (model.getDataType().getType() == DataType.NUCLEOTIDES && model.getCodonHeteroPattern() != null) {
-            for (int i = 1; i <= model.getCodonPartitionCount(); i++) {
-                writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix(i) + "mu");
-            }
-        } else {
-            writer.writeIDref(ParameterParser.PARAMETER, model.getPrefix() + "mu");
-        }
-
-    }
-
     public void writeLog(PartitionSubstitutionModel model, XMLWriter writer) {
 
         int codonPartitionCount = model.getCodonPartitionCount();
@@ -688,8 +650,10 @@ public class SubstitutionModelGenerator extends Generator {
 
         writer.writeCloseTag(GammaSiteModelParser.SUBSTITUTION_MODEL);
 
-        if (model.hasCodon()) {
+        if (model.hasCodonPartitions()) {
             writeParameter(num, GammaSiteModelParser.RELATIVE_RATE, "mu", model, writer);
+        } else {
+            writeParameter(GammaSiteModelParser.RELATIVE_RATE, "mu", model, writer);
         }
 
         if (model.isGammaHetero()) {
@@ -728,6 +692,7 @@ public class SubstitutionModelGenerator extends Generator {
         }
 
         writer.writeCloseTag(GammaSiteModel.SITE_MODEL);
+        writer.writeText("");
     }
 
     /**
@@ -763,9 +728,7 @@ public class SubstitutionModelGenerator extends Generator {
 
         writer.writeCloseTag(GammaSiteModelParser.SUBSTITUTION_MODEL);
 
-        if (model.hasCodon()) {
-            writeParameter(GammaSiteModelParser.RELATIVE_RATE, "mu", model, writer);
-        }
+        writeParameter(GammaSiteModelParser.RELATIVE_RATE, "mu", model, writer);
 
         if (model.isGammaHetero()) {
             writer.writeOpenTag(GammaSiteModelParser.GAMMA_SHAPE,
@@ -800,9 +763,7 @@ public class SubstitutionModelGenerator extends Generator {
         writer.writeIDref(EmpiricalAminoAcidModelParser.EMPIRICAL_AMINO_ACID_MODEL, prefix + "aa");
         writer.writeCloseTag(GammaSiteModelParser.SUBSTITUTION_MODEL);
 
-        if (model.hasCodon()) {
-            writeParameter(GammaSiteModelParser.RELATIVE_RATE, "mu", model, writer);
-        }
+        writeParameter(GammaSiteModelParser.RELATIVE_RATE, "mu", model, writer);
 
 
         if (model.isGammaHetero()) {
