@@ -1,7 +1,7 @@
 /*
  * MCMCPanel.java
  *
- * Copyright (C) 2002-2009 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -12,10 +12,10 @@
  * published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  *
- * BEAST is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with BEAST; if not, write to the
@@ -29,8 +29,8 @@ package dr.app.beauti.mcmcpanel;
 import dr.app.beauti.BeautiFrame;
 import dr.app.beauti.BeautiPanel;
 import dr.app.beauti.components.marginalLikelihoodEstimation.MLEDialog;
+import dr.app.beauti.components.marginalLikelihoodEstimation.MLEGSSDialog;
 import dr.app.beauti.components.marginalLikelihoodEstimation.MarginalLikelihoodEstimationOptions;
-import dr.app.beauti.components.sequenceerror.SequenceErrorModelComponentOptions;
 import dr.app.beauti.options.BeautiOptions;
 import dr.app.beauti.options.PartitionTreeModel;
 import dr.app.beauti.options.STARBEASTOptions;
@@ -62,8 +62,11 @@ public class MCMCPanel extends BeautiPanel {
     WholeNumberField logEveryField = new WholeNumberField(1, Integer.MAX_VALUE);
 
     JCheckBox samplePriorCheckBox = new JCheckBox("Sample from prior only - create empty alignment");
-    JCheckBox performMLE = new JCheckBox("Perform marginal likelihood estimation (MLE) using path sampling/stepping-stone sampling");
+    JComboBox performMLECombo = new JComboBox(new String[] {"None", "path sampling/stepping-stone sampling", "generalized stepping-stone sampling"});
+//    JCheckBox performMLE = new JCheckBox("Perform marginal likelihood estimation (MLE) using path sampling/stepping-stone sampling");
     JButton buttonMLE = new JButton("Settings");
+    //    JCheckBox performMLEGSS = new JCheckBox("Perform marginal likelihood estimation (MLE) using generalized stepping-stone sampling");
+  //  JButton buttonMLEGSS = new JButton("Settings");
 
     public static final String DEFAULT_FILE_NAME_STEM = "untitled";
     JTextField fileNameStemField = new JTextField(DEFAULT_FILE_NAME_STEM);
@@ -80,15 +83,16 @@ public class MCMCPanel extends BeautiPanel {
     JCheckBox substTreeLogCheck = new JCheckBox("Create tree log file with branch length in substitutions:");
     JTextArea substTreeFileNameField = new JTextArea("untitled(subst).trees");
 
-    JCheckBox operatorAnalaysisCheck = new JCheckBox("Create operator analysis file:");
-    JTextArea operatorAnalaysisFileNameField = new JTextArea(DEFAULT_FILE_NAME_STEM + ".ops");
+    JCheckBox operatorAnalysisCheck = new JCheckBox("Create operator analysis file:");
+    JTextArea operatorAnalysisFileNameField = new JTextArea(DEFAULT_FILE_NAME_STEM + ".ops");
 
     BeautiFrame frame = null;
     private final OptionsPanel optionsPanel;
     private BeautiOptions options;
 
     private MLEDialog mleDialog = null;
-    private MarginalLikelihoodEstimationOptions mleOptions;
+    private MLEGSSDialog mleGssDialog = null;
+    private MarginalLikelihoodEstimationOptions mleOptions = new MarginalLikelihoodEstimationOptions();
 
     public MCMCPanel(BeautiFrame parent) {
         setLayout(new BorderLayout());
@@ -235,10 +239,10 @@ public class MCMCPanel extends BeautiPanel {
         substTreeFileNameField.setEnabled(false);
         optionsPanel.addComponentWithLabel("Substitutions trees file name:", substTreeFileNameField);
 
-        optionsPanel.addComponent(operatorAnalaysisCheck);
-        operatorAnalaysisCheck.addActionListener(new java.awt.event.ActionListener() {
+        optionsPanel.addComponent(operatorAnalysisCheck);
+        operatorAnalysisCheck.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(ActionEvent e) {
-                options.operatorAnalysis = operatorAnalaysisCheck.isSelected();
+                options.operatorAnalysis = operatorAnalysisCheck.isSelected();
 
                 updateOtherFileNames(options);
 
@@ -246,10 +250,10 @@ public class MCMCPanel extends BeautiPanel {
             }
         });
 
-        operatorAnalaysisFileNameField.setColumns(32);
-        operatorAnalaysisFileNameField.setEditable(false);
-        operatorAnalaysisFileNameField.setEnabled(false);
-        optionsPanel.addComponentWithLabel("Operator analysis file name:", operatorAnalaysisFileNameField);
+        operatorAnalysisFileNameField.setColumns(32);
+        operatorAnalysisFileNameField.setEditable(false);
+        operatorAnalysisFileNameField.setEnabled(false);
+        optionsPanel.addComponentWithLabel("Operator analysis file name:", operatorAnalysisFileNameField);
 
         optionsPanel.addSeparator();
 
@@ -263,26 +267,39 @@ public class MCMCPanel extends BeautiPanel {
 
         optionsPanel.addSeparator();
 
-        JTextArea mleInfo = new JTextArea("Select the option below to perform marginal likelihoood " +
+        JTextArea mleInfo = new JTextArea("Select the option below to perform marginal likelihood " +
                 "estimation (MLE) using path sampling (PS) / stepping-stone sampling (SS) " +
-                "which performs an additional analysis after the standard MCMC chain has finished.");
+                "or generalized stepping-stone sampling (GSS) which performs an additional" +
+                "analysis after the standard MCMC chain has finished.");
         mleInfo.setColumns(50);
         PanelUtils.setupComponent(mleInfo);
         optionsPanel.addSpanningComponent(mleInfo);
 
-        optionsPanel.addComponent(performMLE);
-        //will be false by default
-        //options.performMLE = false;
+        //add PS/SS button
+        optionsPanel.addComponentWithLabel("Marginal likelihood estimation (MLE):", performMLECombo);
+
         optionsPanel.addComponent(buttonMLE);
         buttonMLE.setEnabled(false);
-        performMLE.addActionListener(new java.awt.event.ActionListener() {
+        performMLECombo.addActionListener(new java.awt.event.ActionListener() {
             public void actionPerformed(ActionEvent e) {
-                if (performMLE.isSelected()) {
+                if (performMLECombo.getSelectedIndex() == 1) {
                     mleOptions.performMLE = true;
+                    mleOptions.performMLEGSS = false;
+                    options.logCoalescentEventsStatistic = false;
+                    buttonMLE.setEnabled(true);
+                    updateMLEFileNameStem();
+                } else if (performMLECombo.getSelectedIndex() == 2) {
+                    mleOptions.performMLE = false;
+                    mleOptions.performMLEGSS = true;
+                    //set to true because product of exponentials is the default option
+                    options.logCoalescentEventsStatistic = true;
                     buttonMLE.setEnabled(true);
                     updateMLEFileNameStem();
                 } else {
                     mleOptions.performMLE = false;
+                    mleOptions.performMLEGSS = false;
+                    mleOptions.printOperatorAnalysis = false;
+                    options.logCoalescentEventsStatistic = false;
                     buttonMLE.setEnabled(false);
                 }
             }
@@ -291,7 +308,13 @@ public class MCMCPanel extends BeautiPanel {
             public void actionPerformed(ActionEvent e) {
                 updateMLEFileNameStem();
 
-                int result = mleDialog.showDialog();
+                int result = -1;
+
+                if (performMLECombo.getSelectedIndex() == 1) {
+                   result  = mleDialog.showDialog();
+                } else if (performMLECombo.getSelectedIndex() == 2) {
+                    result = mleGssDialog.showDialog();
+                }
 
                 if (result == -1 || result == JOptionPane.CANCEL_OPTION) {
                     return;
@@ -300,6 +323,52 @@ public class MCMCPanel extends BeautiPanel {
             }
         });
 
+//        JTextArea mleGssInfo = new JTextArea("Select the option below to perform marginal likelihood " +
+//                "estimation (MLE) using generalized stepping-stone sampling (GSS) which " +
+//                "performs an additional analysis after the standard MCMC chain has finished.");
+//        mleGssInfo.setColumns(50);
+//        PanelUtils.setupComponent(mleGssInfo);
+//        optionsPanel.addSpanningComponent(mleGssInfo);
+
+//        //add GSS button
+//        optionsPanel.addComponent(performMLEGSS);
+//        //will be false by default
+//        //options.performMLE = false; ??
+//        optionsPanel.addComponent(buttonMLEGSS);
+//        buttonMLEGSS.setEnabled(false);
+//        performMLEGSS.addActionListener(new java.awt.event.ActionListener() {
+//            public void actionPerformed(ActionEvent e) {
+//                if (performMLEGSS.isSelected()) {
+//                    mleOptions.performMLEGSS = true;
+//                    //set to true because product of exponentials is the default option
+//                    options.logCoalescentEventsStatistic = true;
+//                    buttonMLEGSS.setEnabled(true);
+//                    buttonMLE.setEnabled(false);
+//                    performMLE.setEnabled(false);
+//                    updateMLEFileNameStem();
+//                } else {
+//                    mleOptions.performMLEGSS = false;
+//                    mleOptions.printOperatorAnalysis = false;
+//                    options.logCoalescentEventsStatistic = false;
+//                    buttonMLE.setEnabled(false);
+//                    performMLE.setEnabled(true);
+//                    buttonMLEGSS.setEnabled(false);
+//                }
+//            }
+//        });
+//        buttonMLEGSS.addActionListener(new java.awt.event.ActionListener() {
+//            public void actionPerformed(ActionEvent e) {
+//                updateMLEFileNameStem();
+//
+//                int result = mleGssDialog.showDialog();
+//
+//                if (result == -1 || result == JOptionPane.CANCEL_OPTION) {
+//                    return;
+//                }
+//
+//            }
+//        });
+
 //        logFileNameField.addKeyListener(listener);
 //        treeFileNameField.addKeyListener(listener);
         //mapTreeFileNameField.addKeyListener(listener);
@@ -363,11 +432,27 @@ public class MCMCPanel extends BeautiPanel {
     public void setOptions(BeautiOptions options) {
         this.options = options;
 
+        /*System.err.println("mleOptions: " + mleOptions);
+        System.err.println("options.pathSteps: " + mleOptions.pathSteps);
+        System.err.println("options.mleChainLength: " + mleOptions.mleChainLength);
+        System.err.println("options.mleLogEvery: " + mleOptions.mleLogEvery);*/
+
         // get the MLE options
         mleOptions = (MarginalLikelihoodEstimationOptions)options.getComponentOptions(MarginalLikelihoodEstimationOptions.class);
+        /*if (mleOptions == null) {
+            mleOptions = new MarginalLikelihoodEstimationOptions();
+        }*/
+
+        /*System.err.println("mleOptions: " + mleOptions);
+        System.err.println("options.pathSteps: " + mleOptions.pathSteps);
+        System.err.println("options.mleChainLength: " + mleOptions.mleChainLength);
+        System.err.println("options.mleLogEvery: " + mleOptions.mleLogEvery);*/
 
         if (mleDialog != null) {
-            mleDialog.setOptions(mleOptions);
+            //mleDialog.setOptions(mleOptions);
+        }
+        if (mleGssDialog != null) {
+            //mleGssDialog.setOptions(mleOptions);
         }
 
         chainLengthField.setValue(options.chainLength);
@@ -381,7 +466,7 @@ public class MCMCPanel extends BeautiPanel {
             fileNameStemField.setEnabled(false);
         }
 
-        operatorAnalaysisCheck.setSelected(options.operatorAnalysis);
+        operatorAnalysisCheck.setSelected(options.operatorAnalysis);
 
         updateOtherFileNames(options);
 
@@ -424,11 +509,11 @@ public class MCMCPanel extends BeautiPanel {
             if (addTxt.isSelected()) {
                 options.operatorAnalysisFileName = options.operatorAnalysisFileName + ".txt";
             }
-            operatorAnalaysisFileNameField.setEnabled(options.operatorAnalysis);
+            operatorAnalysisFileNameField.setEnabled(options.operatorAnalysis);
             if (options.operatorAnalysis) {
-                operatorAnalaysisFileNameField.setText(options.operatorAnalysisFileName);
+                operatorAnalysisFileNameField.setText(options.operatorAnalysisFileName);
             } else {
-                operatorAnalaysisFileNameField.setText("");
+                operatorAnalysisFileNameField.setText("");
             }
 
 //            mapTreeLogCheck.setEnabled(true);
@@ -450,8 +535,8 @@ public class MCMCPanel extends BeautiPanel {
             substTreeLogCheck.setSelected(false);
             substTreeFileNameField.setEnabled(false);
             substTreeFileNameField.setText("");
-            operatorAnalaysisCheck.setSelected(false);
-            operatorAnalaysisFileNameField.setText("");
+            operatorAnalysisCheck.setSelected(false);
+            operatorAnalysisFileNameField.setText("");
         }
     }
 
@@ -459,7 +544,11 @@ public class MCMCPanel extends BeautiPanel {
         if (mleDialog == null) {
             mleDialog = new MLEDialog(frame, mleOptions);
         }
+        if (mleGssDialog == null) {
+            mleGssDialog = new MLEGSSDialog(frame, mleOptions, options);
+        }
         mleDialog.setFilenameStem(options.fileNameStem, addTxt.isSelected());
+        mleGssDialog.setFilenameStem(options.fileNameStem, addTxt.isSelected());
     }
 
     public void getOptions(BeautiOptions options) {
@@ -472,13 +561,17 @@ public class MCMCPanel extends BeautiPanel {
         options.substTreeLog = substTreeLogCheck.isSelected();
         updateTreeFileNameList();
 
-        options.operatorAnalysis = operatorAnalaysisCheck.isSelected();
-        options.operatorAnalysisFileName = operatorAnalaysisFileNameField.getText();
+        options.operatorAnalysis = operatorAnalysisCheck.isSelected();
+        options.operatorAnalysisFileName = operatorAnalysisFileNameField.getText();
 
         options.samplePriorOnly = samplePriorCheckBox.isSelected();
 
         if (mleDialog != null) {
-            mleDialog.getOptions(mleOptions);
+            //mleDialog.getOptions(mleOptions);
+        }
+
+        if (mleGssDialog != null) {
+            //mleGssDialog.getOptions(mleOptions);
         }
 
     }
