@@ -52,9 +52,9 @@ public class ModelOptions implements Serializable {
     public static final double demoTuning = 0.75;
     public static final double demoWeights = 3.0;
 
-    protected static final double branchWeights = 30.0;
-    protected static final double treeWeights = 15.0;
-    protected static final double rateWeights = 3.0;
+	protected static final double branchWeights = 30.0;
+	protected static final double treeWeights = 15.0;
+	protected static final double rateWeights = 3.0;
 
     private final List<ComponentOptions> components = new ArrayList<ComponentOptions>();
 
@@ -67,14 +67,28 @@ public class ModelOptions implements Serializable {
         return new Parameter.Builder(name, description).initial(initial).isFixed(true).build(parameters);
     }
 
+    public Parameter createZeroOneParameter(String name, String description, double initial) {
+        return new Parameter.Builder(name, description)
+                .initial(initial).isZeroOne(true).build(parameters);
+    }
+
     public Parameter createZeroOneParameterUniformPrior(String name, String description, double initial) {
         return new Parameter.Builder(name, description).prior(PriorType.UNIFORM_PRIOR)
                 .initial(initial).isZeroOne(true).build(parameters);
     }
 
+    public Parameter createNonNegativeParameterDirichletPrior(String name, String description, PartitionOptions options, PriorScaleType scaleType, double initial) {
+        return new Parameter.Builder(name, description).scaleType(scaleType).prior(PriorType.DIRICHLET_PRIOR).isNonNegative(true)
+                .partitionOptions(options).initial(initial).build(parameters);
+    }
+
     public Parameter createNonNegativeParameterInfinitePrior(String name, String description, PriorScaleType scaleType, double initial) {
+        return createNonNegativeParameterInfinitePrior(name, description, null, scaleType, initial);
+    }
+
+    public Parameter createNonNegativeParameterInfinitePrior(String name, String description, PartitionOptions options, PriorScaleType scaleType, double initial) {
         return new Parameter.Builder(name, description).scaleType(scaleType).prior(PriorType.NONE_IMPROPER).isNonNegative(true)
-                .initial(initial).build(parameters);
+                .partitionOptions(options).initial(initial).build(parameters);
     }
 
     public Parameter createNonNegativeParameterUniformPrior(String name, String description, PriorScaleType scaleType, double initial,
@@ -156,7 +170,15 @@ public class ModelOptions implements Serializable {
     //+++++++++++++++++++ Create Operator ++++++++++++++++++++++++++++++++
     public Operator createOperator(String parameterName, OperatorType type, double tuning, double weight) {
         Parameter parameter = getParameter(parameterName);
-        return new Operator.Builder(parameterName, parameterName, parameter, type, tuning, weight).build(operators);
+        return new Operator.Builder(parameterName, parameterName, parameter, type, tuning, weight)
+                .build(operators);
+    }
+
+    public Operator createOperator(String parameterName, OperatorType type, double tuning, double weight, boolean autoOptimize) {
+        Parameter parameter = getParameter(parameterName);
+        return new Operator.Builder(parameterName, parameterName, parameter, type, tuning, weight)
+                .autoOptimize(autoOptimize)
+                .build(operators);
     }
 
     public Operator createScaleOperator(String parameterName, double tuning, double weight) {
@@ -218,7 +240,7 @@ public class ModelOptions implements Serializable {
     }//TODO a switch like createUpDownOperator?
 
     public Operator createDuplicate(String name, String description, Parameter parameter, Operator source) {
-        return new Operator.Builder(name, description, parameter, source.operatorType, source.tuning, source.weight).build(operators);
+        return new Operator.Builder(name, description, parameter, source.getOperatorType(), source.getTuning(), source.getWeight()).build(operators);
     }
 
 
