@@ -1,5 +1,7 @@
 /*
- * Copyright (C) 2002-2009 Alexei Drummond and Andrew Rambaut
+ * Operator.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -10,10 +12,10 @@
  * published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  *
- * BEAST is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with BEAST; if not, write to the
@@ -41,20 +43,21 @@ public class Operator implements Serializable {
     // final
     private String baseName;
     private final String description;
-    public final OperatorType operatorType;
-    public final Parameter parameter1;
-    public final Parameter parameter2;
+    private final OperatorType operatorType;
+    private final Parameter parameter1;
+    private final Parameter parameter2;
     private final PartitionOptions options;
-    public final String tag;
+    private final String tag;
 
     // editable
-    public double tuning;
-    public double weight;
-    public boolean tuningEdited;
-    public boolean inUse;
-    public String idref;
+    private double tuning;
+    private double weight;
+    private boolean tuningEdited = false;
+    private boolean isUsed = true;
 
-    private ClockModelGroup clockModelGroup = null;
+    private boolean autoOptimize = true;
+
+    private String idref;
 
     public static class Builder {
         // Required para
@@ -72,8 +75,7 @@ public class Operator implements Serializable {
         private String tag = null;
         private String idref = null;
 
-        private boolean inUse = true;
-        private boolean tuningEdited = false;
+        private boolean autoOptimize = true;
 
         public Builder(String name, String description, Parameter parameter, OperatorType type, double tuning, double weight) {
             this.baseName = name;
@@ -84,21 +86,12 @@ public class Operator implements Serializable {
             this.weight = weight;
         }
 
+
         public Builder parameter2(Parameter parameter2) {
             this.parameter2 = parameter2;
             return this;
         }
 
-        public Builder isInUse(boolean inUse) {
-            this.inUse = inUse;
-            return this;
-        }
-
-        public Builder tuningEdited(boolean tuningEdited) {
-            this.tuningEdited = tuningEdited;
-            return this;
-        }
-
         public Builder partitionOptions(PartitionOptions options) {
             this.options = options;
             return this;
@@ -108,11 +101,17 @@ public class Operator implements Serializable {
             this.tag = tag;
             return this;
         }
+
         public Builder idref(String idref) {
             this.idref = idref;
             return this;
         }
 
+        public Builder autoOptimize(boolean autoOptimize) {
+            this.autoOptimize = autoOptimize;
+            return this;
+        }
+
         public Operator build() {
             return new Operator(this);
         }
@@ -135,8 +134,9 @@ public class Operator implements Serializable {
         options = builder.options;
         tag = builder.tag;
         idref = builder.idref;
-        inUse = builder.inUse;
-        tuningEdited = builder.tuningEdited;
+        isUsed = true;
+        tuningEdited = false;
+        autoOptimize = builder.autoOptimize;
     }
 
     //+++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -158,6 +158,63 @@ public class Operator implements Serializable {
         return tuning > 0;
     }
 
+    public String getTag() {
+        return tag;
+    }
+
+    public String getIdref() {
+        return idref;
+    }
+
+    public double getWeight() {
+        return weight;
+    }
+
+    public void setWeight(double weight) {
+        this.weight = weight;
+    }
+
+    public double getTuning() {
+        return tuning;
+    }
+
+    public void setTuning(double tuning) {
+        this.tuning = tuning;
+        tuningEdited = true;
+    }
+
+    public boolean isTuningEdited() {
+        return tuningEdited;
+    }
+
+    public OperatorType getOperatorType() {
+        return operatorType;
+    }
+
+    public boolean isUsed() {
+        return isParameterFixed() ? false : isUsed;
+    }
+
+    public void setUsed(boolean used) {
+        this.isUsed = used;
+    }
+
+    public boolean isAutoOptimize() {
+        return autoOptimize;
+    }
+
+    public boolean isParameterFixed() {
+        return parameter1.isFixed();
+    }
+
+    public Parameter getParameter1() {
+        return parameter1;
+    }
+
+    public Parameter getParameter2() {
+        return parameter2;
+    }
+
     public void setPrefix(String prefix) {
         this.prefix = prefix;
     }
@@ -186,12 +243,4 @@ public class Operator implements Serializable {
         return baseName;
     }
 
-    public ClockModelGroup getClockModelGroup() {
-        return clockModelGroup;
-    }
-
-    public void setClockModelGroup(ClockModelGroup clockModelGroup) {
-        this.clockModelGroup = clockModelGroup;
-    }
-
 }
