@@ -25,11 +25,14 @@
 
 package dr.app.beauti.options;
 
+import cern.colt.bitvector.QuickBitVector;
 import dr.app.beauti.types.PriorScaleType;
 import dr.app.beauti.types.PriorType;
 import dr.math.distributions.Distribution;
 
 import java.io.Serializable;
+import java.util.ArrayList;
+import java.util.List;
 import java.util.Map;
 
 /**
@@ -50,6 +53,10 @@ public class Parameter implements Serializable {
     private String baseName;
     private final String description;
 
+    private int dimensionWeight = 1;
+
+    private final List<Parameter> subParameters = new ArrayList<Parameter>();
+
     // final Builder para
     public String taxaId; // needs to change TMRCA stat name. Issue 520
     public final boolean isNodeHeight;
@@ -71,9 +78,17 @@ public class Parameter implements Serializable {
     public final boolean isPriorFixed;
     public PriorType priorType;
 
+    public double getInitial() {
+        return initial;
+    }
+
+    public void setInitial(double initial) {
+        this.initial = initial;
+    }
+
     // Editable fields
-    public boolean isFixed;
-    public double initial;
+    private boolean isFixed;
+    private double initial;
     public boolean isTruncated;
     public double truncationUpper;
     public double truncationLower;
@@ -471,7 +486,9 @@ public class Parameter implements Serializable {
         double upper = Double.POSITIVE_INFINITY;
 
         if (isZeroOne) {
-            if (upper > 1) upper = 1.0;
+            if (upper > 1) {
+                upper = 1.0;
+            }
         }
 
         if (priorType == PriorType.UNIFORM_PRIOR) {
@@ -485,6 +502,16 @@ public class Parameter implements Serializable {
         return upper;
     }
 
+    public boolean isFixed() {
+        return priorType == PriorType.NONE_FIXED;
+    }
+
+    public void setFixed(boolean isFixed) {
+        if (isFixed) {
+            priorType = PriorType.NONE_FIXED;
+        }
+    }
+
     public boolean isMeanInRealSpace() {
         return meanInRealSpace;
     }
@@ -493,6 +520,40 @@ public class Parameter implements Serializable {
         this.meanInRealSpace = meanInRealSpace;
     }
 
+    public int[] getParameterDimensionWeights() {
+//        if (getOptions() != null && getOptions() instanceof PartitionSubstitutionModel) {
+//            return ((PartitionSubstitutionModel)getOptions()).getPartitionCodonWeights();
+//        }
+        if (getSubParameters().size() > 0) {
+            int[] weights = new int[getSubParameters().size()];
+            for (int i = 0; i < weights.length; i++) {
+                weights[i] = getSubParameters().get(i).getDimensionWeight();
+            }
+            return weights;
+        }
+        return new int[] { dimensionWeight };
+    }
+
+    public int getDimensionWeight() {
+        return dimensionWeight;
+    }
+
+    public void setDimensionWeight(int dimensionWeight) {
+        this.dimensionWeight = dimensionWeight;
+    }
+
+    public void addSubParameter(Parameter parameter) {
+        subParameters.add(parameter);
+    }
+
+    public void clearSubParameters() {
+        subParameters.clear();
+    }
+
+    public List<Parameter> getSubParameters() {
+        return subParameters;
+    }
+
     @Override
     public String toString() {
         return getName();
