@@ -1,3 +1,28 @@
+/*
+ * PriorOptionsPanel.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.app.beauti.priorsPanel;
 
 import dr.app.beauti.options.Parameter;
@@ -67,7 +92,7 @@ abstract class PriorOptionsPanel extends OptionsPanel {
     private List<JComponent> argumentFields = new ArrayList<JComponent>();
     private List<String> argumentNames = new ArrayList<String>();
 
-    private boolean isCalibratedYule = true;
+    private boolean isCalibratedYule = false;
     private boolean isInitializable = true;
     private final boolean isTruncatable;
 
@@ -320,10 +345,10 @@ abstract class PriorOptionsPanel extends OptionsPanel {
 
     void setArguments(Parameter parameter, PriorType priorType) {
         this.isCalibratedYule = parameter.isCalibratedYule;
-        this.isInitializable = priorType.isInitializable;
-        if (!parameter.isStatistic) {
+        this.isInitializable = priorType.isInitializable && !parameter.isStatistic && !parameter.isNodeHeight;
+        if (!parameter.isStatistic && !parameter.isNodeHeight) {
             setFieldRange(initialField, parameter.isNonNegative, parameter.isZeroOne);
-            initialField.setValue(parameter.initial);
+            initialField.setValue(parameter.getInitial());
         }
         isTruncatedCheck.setSelected(parameter.isTruncated);
         setFieldRange(lowerField, parameter.isNonNegative, parameter.isZeroOne, Double.NEGATIVE_INFINITY, Double.POSITIVE_INFINITY);
@@ -339,8 +364,8 @@ abstract class PriorOptionsPanel extends OptionsPanel {
     }
 
     void getArguments(Parameter parameter, PriorType priorType) {
-        if (priorType.isInitializable) {
-            parameter.initial = initialField.getValue();
+        if (priorType.isInitializable && !parameter.isStatistic && !parameter.isNodeHeight) {
+            parameter.setInitial(initialField.getValue());
         }
         parameter.isTruncated = isTruncatedCheck.isSelected();
         if (parameter.isTruncated) {
