@@ -1,7 +1,7 @@
 /*
  * PartitionModelPanel.java
  *
- * Copyright (c) 2002-2011 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -62,7 +62,7 @@ public class PartitionModelPanel extends OptionsPanel {
     private static final long serialVersionUID = -1645661616353099424L;
 
     private JComboBox nucSubstCombo = new JComboBox(EnumSet.range(
-            NucModelType.HKY, NucModelType.TN93).toArray());
+            NucModelType.JC, NucModelType.TN93).toArray());
     private JComboBox aaSubstCombo = new JComboBox(AminoAcidModelType.values());
     private JComboBox binarySubstCombo = new JComboBox(
             new BinaryModelType[] { BinaryModelType.BIN_SIMPLE, BinaryModelType.BIN_COVARION });
@@ -149,6 +149,12 @@ public class PartitionModelPanel extends OptionsPanel {
             public void itemStateChanged(ItemEvent ev) {
                 model.setNucSubstitutionModel((NucModelType) nucSubstCombo
                         .getSelectedItem());
+                if (model.getNucSubstitutionModel() == NucModelType.JC) {
+                    frequencyCombo.getSelectedItem();
+
+                    frequencyCombo.setSelectedItem(FrequencyPolicyType.ALLEQUAL);
+                }
+                frequencyCombo.setEnabled(model.getNucSubstitutionModel() != NucModelType.JC);
             }
         });
         nucSubstCombo
@@ -597,7 +603,7 @@ public class PartitionModelPanel extends OptionsPanel {
      * position model
      */
     private void setSRD06Model() {
-        nucSubstCombo.setSelectedIndex(0);
+        nucSubstCombo.setSelectedIndex(1);
         heteroCombo.setSelectedIndex(1);
         codingCombo.setSelectedIndex(1);
         substUnlinkCheck.setSelected(true);
