@@ -462,10 +462,14 @@ public class PartitionTreePriorPanel extends OptionsPanel {
 
         } else {
 
-            for (TreePriorType treePriorType : EnumSet.range(TreePriorType.CONSTANT, TreePriorType.BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER)) {
+            for (TreePriorType treePriorType : EnumSet.range(TreePriorType.CONSTANT, TreePriorType.BIRTH_DEATH_SERIAL_SAMPLING)) {
                 treePriorCombo.addItem(treePriorType);
             }
 
+            // REMOVED due to unresolved issues with model
+            // treePriorCombo.addItem(TreePriorType.BIRTH_DEATH_BASIC_REPRODUCTIVE_NUMBER);
+
+
             // would be much better to disable these rather than removing them
             if (isMultiLocus) {
                 treePriorCombo.removeItem(TreePriorType.SKYLINE);
