@@ -211,11 +211,6 @@ public class TreesPanel extends BeautiPanel implements Exportable {
 
                 options.getPartitionTreePriors().get(0).setNodeHeightPrior(TreePriorType.SPECIES_YULE);
 
-                List<ClockModelGroup> groupList = options.clockModelOptions.getClockModelGroups();// all data partitions
-                for (ClockModelGroup clockModelGroup : groupList) { // todo correct?
-                    options.clockModelOptions.fixRateOfFirstClockPartition(clockModelGroup); // fix 1st partition
-                }
-
             } else {
 //                if (options.hasData() && options.contains(Microsatellite.INSTANCE)) {
 //                    linkTreePriorCheck.setEnabled(false);
