@@ -1,3 +1,28 @@
+/*
+ * BeagleSequenceSimulatorApp.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.app.bss;
 
 import jam.framework.SingleDocApplication;
@@ -24,8 +49,8 @@ public class BeagleSequenceSimulatorApp {
 	// Share those if neccessary
 	public static final String SHORT_NAME = "\u03C0BUSS";
 	public static final String LONG_NAME = "Parallel BEAST/BEAGLE Utility for Sequence Simulation";
-	public static final String VERSION = "1.3.7";
-	public static final String DATE = "2014";
+	public static final String VERSION = "1.3.8rc";
+	public static final String DATE = "2015";
 
 	// Icons
 	private Image beagleSequenceSimulatorImage;
@@ -124,9 +149,17 @@ public class BeagleSequenceSimulatorApp {
 		
 		if (args.length > 0) {
 			
+			try {
+			
 				BeagleSequenceSimulatorConsoleApp app = new BeagleSequenceSimulatorConsoleApp();
 				app.simulate(args);
 				
+			} catch (UnsupportedClassVersionError e) {
+
+				Utils.handleException(e, "Your Java Runtime Environment is too old. Please update");
+
+			}//END: try-catch block
+				
 		} else {
 
 			try {
@@ -139,17 +172,16 @@ public class BeagleSequenceSimulatorApp {
 
 			} catch (UnsupportedClassVersionError e) {
 
-				System.out
-						.println("Your Java Runtime Environment is too old. Please update");
-
+				Utils.handleException(e, "Your Java Runtime Environment is too old. Please update");
+				
 			} catch (ClassNotFoundException e) {
-				e.printStackTrace();
+				Utils.handleException(e, e.getMessage());
 			} catch (InstantiationException e) {
-				e.printStackTrace();
+				Utils.handleException(e, e.getMessage());
 			} catch (IllegalAccessException e) {
-				e.printStackTrace();
+				Utils.handleException(e, e.getMessage());
 			} catch (UnsupportedLookAndFeelException e) {
-				e.printStackTrace();
+				Utils.handleException(e, e.getMessage());
 			}// END: try catch block
 
 		}// END: command line check
