@@ -1,7 +1,7 @@
 /*
  * BeagleSeqSimTest.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -690,8 +690,8 @@ public class BeagleSeqSimTest {
 
 			if (calculateLikelihood) {
 
-				// NewBeagleTreeLikelihood nbtl = new
-				// NewBeagleTreeLikelihood(alignment, treeModel,
+				// NewBeagleSequenceLikelihood nbtl = new
+				// NewBeagleSequenceLikelihood(alignment, treeModel,
 				// substitutionModel, (SiteModel) siteRateModel,
 				// branchRateModel, null, false,
 				// PartialsRescalingScheme.DEFAULT);
@@ -706,7 +706,7 @@ public class BeagleSeqSimTest {
 						branchRateModel, //
 						null, //
 						false, //
-						PartialsRescalingScheme.DEFAULT);
+						PartialsRescalingScheme.DEFAULT, true);
 
 				System.out.println("likelihood = " + nbtl.getLogLikelihood());
 
