@@ -109,19 +109,40 @@ public class TracerMacFileMenuFactory implements MenuFactory {
 
         menu.addSeparator();
 
-        item = new JMenuItem(frame.getCloseWindowAction());
-        item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_W, MenuBarFactory.MENU_MASK));
-        menu.add(item);
+        if (frame != null) {
+            item = new JMenuItem(frame.getCloseWindowAction());
+            item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_W, MenuBarFactory.MENU_MASK));
+            menu.add(item);
 
-        menu.addSeparator();
+            menu.addSeparator();
 
-        item = new JMenuItem(frame.getPrintAction());
-        item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, MenuBarFactory.MENU_MASK));
-        menu.add(item);
+            item = new JMenuItem(frame.getPrintAction());
+            item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, MenuBarFactory.MENU_MASK));
+            menu.add(item);
 
-        item = new JMenuItem(application.getPageSetupAction());
-        item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, MenuBarFactory.MENU_MASK + ActionEvent.SHIFT_MASK));
-        menu.add(item);
+            item = new JMenuItem(application.getPageSetupAction());
+            item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, MenuBarFactory.MENU_MASK + ActionEvent.SHIFT_MASK));
+            menu.add(item);
+
+        } else {
+            // No frame available so create a disabled menu for the default menu bar
+            item = new JMenuItem("Close");
+            item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_W, MenuBarFactory.MENU_MASK));
+            item.setEnabled(false);
+            menu.add(item);
+
+            menu.addSeparator();
+
+            item = new JMenuItem("Print...");
+            item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, MenuBarFactory.MENU_MASK));
+            item.setEnabled(false);
+            menu.add(item);
+
+            item = new JMenuItem("Page Setup...");
+            item.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_P, MenuBarFactory.MENU_MASK + ActionEvent.SHIFT_MASK));
+            item.setEnabled(false);
+            menu.add(item);
+        }
 
     }
 
