@@ -49,7 +49,7 @@ public class SimpleSiteList implements SiteList {
     private int siteCount = 0;
     private int[][] sitePatterns = new int[0][];
 
-    public SimpleSiteList(DataType dataType) {
+	public SimpleSiteList(DataType dataType) {
         this.taxonList = null;
         this.dataType = dataType;
     }
@@ -184,6 +184,11 @@ public class SimpleSiteList implements SiteList {
 		return Utils.empiricalStateFrequencies(this);
 	}
 
+	@Override
+	public boolean areUnique() {
+		return false;
+	}
+
 	// **************************************************************
 	// TaxonList IMPLEMENTATION
 	// **************************************************************
