@@ -40,12 +40,8 @@ import dr.inference.model.CompoundParameter;
 import dr.inference.model.Model;
 import dr.inference.model.Parameter;
 import dr.inference.model.Variable;
-import dr.inference.operators.MCMCOperator;
 import dr.math.GammaFunction;
-import dr.math.distributions.MultivariateNormalDistribution;
-import dr.math.matrixAlgebra.SymmetricMatrix;
 import dr.xml.AbstractXMLObjectParser;
-import dr.xml.AttributeRule;
 import dr.xml.ElementRule;
 import dr.xml.StringAttributeRule;
 import dr.xml.XMLObject;
