@@ -1,7 +1,7 @@
 /*
  * DiscretizedBranchRates.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -35,6 +35,12 @@ import dr.inference.model.Model;
 import dr.inference.model.Parameter;
 import dr.inference.model.Variable;
 import dr.math.MathUtils;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.List;
 
 /**
  * @author Alexei Drummond
@@ -42,13 +48,13 @@ import dr.math.MathUtils;
  * @author Michael Defoin Platel
  * @version $Id: DiscretizedBranchRates.java,v 1.11 2006/01/09 17:44:30 rambaut Exp $
  */
-public class DiscretizedBranchRates extends AbstractBranchRateModel {
+public class DiscretizedBranchRates extends AbstractBranchRateModel implements Citable {
     // Turn on an off the caching on rates for categories -
     // if off then the rates will be flagged to update on
     // a restore.
     // Currently turned off as it is not working with multiple partitions for
     // some reason.
-    private static final boolean CACHE_RATES = false;
+    private static final boolean DEFAULT_CACHE_RATES = false;
 
     private final ParametricDistributionModel distributionModel;
 
@@ -71,6 +77,8 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
     private int currentRateArrayIndex = 0;
     private int storedRateArrayIndex;
 
+    private boolean cacheRates = DEFAULT_CACHE_RATES;
+
     //overSampling control the number of effective categories
 
     public DiscretizedBranchRates(
@@ -78,7 +86,7 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
             Parameter rateCategoryParameter,
             ParametricDistributionModel model,
             int overSampling) {
-        this(tree, rateCategoryParameter, model, overSampling, false, Double.NaN, false, false);
+        this(tree, rateCategoryParameter, model, overSampling, false, Double.NaN, false, false, DEFAULT_CACHE_RATES);
 
     }
 
@@ -90,10 +98,13 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
             boolean normalize,
             double normalizeBranchRateTo,
             boolean randomizeRates,
-            boolean keepRates) {
+            boolean keepRates,
+            boolean cacheRates) {
 
         super(DiscretizedBranchRatesParser.DISCRETIZED_BRANCH_RATES);
 
+        this.cacheRates = cacheRates;
+
         this.rateCategories = new TreeParameterModel(tree, rateCategoryParameter, false);
 
         categoryCount = (tree.getNodeCount() - 1) * overSampling;
@@ -143,7 +154,7 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
         for (int i = 0; i < treeModel.getNodeCount(); i++) {
             NodeRef node = treeModel.getNode(i);
             if (!treeModel.isRoot(node)) {
-                int rateCategory = (int) Math.round(rateCategories.getNodeValue(treeModel, node));
+                int rateCategory = (int) (rateCategories.getNodeValue(treeModel, node) + 0.5);
                 treeRate += rates[currentRateArrayIndex][rateCategory] * treeModel.getBranchLength(node);
                 treeTime += treeModel.getBranchLength(node);
 
@@ -170,14 +181,14 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
    }
 
     protected void storeState() {
-        if (CACHE_RATES) {
+        if (cacheRates) {
             storedRateArrayIndex = currentRateArrayIndex;
             storedScaleFactor = scaleFactor;
         }
     }
 
     protected void restoreState() {
-        if (CACHE_RATES) {
+        if (cacheRates) {
             currentRateArrayIndex = storedRateArrayIndex;
             scaleFactor = storedScaleFactor;
         } else {
@@ -196,7 +207,7 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
             setupRates();
         }
 
-        int rateCategory = (int) Math.round(rateCategories.getNodeValue(tree, node));
+        int rateCategory = (int) (rateCategories.getNodeValue(tree, node) + 0.5);
 
         //System.out.println(rates[rateCategory] + "\t"  + rateCategory);
         return rates[currentRateArrayIndex][rateCategory] * scaleFactor;
@@ -207,7 +218,7 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
      */
     private void setupRates() {
 
-        if (CACHE_RATES) {
+        if (cacheRates) {
             // flip the current array index
             currentRateArrayIndex = 1 - currentRateArrayIndex;
         }
@@ -227,4 +238,33 @@ public class DiscretizedBranchRates extends AbstractBranchRateModel {
     public double getLogLikelihood() {
         return logDensityNormalizationConstant;
     }
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.MOLECULAR_CLOCK;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Uncorrelated relaxed clock";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("AJ", "Drummond"),
+                    new Author("SYW", "Ho"),
+                    new Author("MJ", "Phillips"),
+                    new Author("A", "Rambaut")
+            },
+            "Relaxed Phylogenetics and Dating with Confidence",
+            2006,
+            "PLoS Biology",
+            "4: e88",
+            "10.1371/journal.pbio.0040088"
+    );
 }
