@@ -84,6 +84,8 @@ public abstract class AbstractCoalescentLikelihood extends AbstractModelLikeliho
         storedIntervals = new Intervals(tree.getNodeCount());
         eventsKnown = false;
 
+        this.coalescentEventStatisticValues = new double[getNumberOfCoalescentEvents()];
+
         addStatistic(new DeltaStatistic());
 
         likelihoodKnown = false;
@@ -267,6 +269,10 @@ public abstract class AbstractCoalescentLikelihood extends AbstractModelLikeliho
         return intervals.getIntervalCount();
     }
 
+    public int getNumberOfCoalescentEvents() {
+        return tree.getExternalNodeCount()-1;
+    }
+
     public int getCoalescentIntervalLineageCount(int i) {
         if (!eventsKnown) {
             setupIntervals();
@@ -281,6 +287,24 @@ public abstract class AbstractCoalescentLikelihood extends AbstractModelLikeliho
         return intervals.getIntervalType(i);
     }
 
+    public double getCoalescentEventsStatisticValue(int i) {
+        if (i == 0) {
+            for (int j = 0; j < coalescentEventStatisticValues.length; j++) {
+                coalescentEventStatisticValues[j] = 0.0;
+            }
+            int counter = 0;
+            for (int j = 0; j < getCoalescentIntervalDimension(); j++) {
+                if (getCoalescentIntervalType(j) == IntervalType.COALESCENT) {
+                    this.coalescentEventStatisticValues[counter] += getCoalescentInterval(j) * (getCoalescentIntervalLineageCount(j) * (getCoalescentIntervalLineageCount(j) - 1.0)) / 2.0;
+                    counter++;
+                } else {
+                    this.coalescentEventStatisticValues[counter] += getCoalescentInterval(j) * (getCoalescentIntervalLineageCount(j) * (getCoalescentIntervalLineageCount(j) - 1.0)) / 2.0;
+                }
+            }
+        }
+        return coalescentEventStatisticValues[i];
+    }
+
     public String toString() {
         return Double.toString(logLikelihood);
 
@@ -335,4 +359,6 @@ public abstract class AbstractCoalescentLikelihood extends AbstractModelLikeliho
     private double storedLogLikelihood;
     protected boolean likelihoodKnown = false;
     private boolean storedLikelihoodKnown = false;
+
+    private double[] coalescentEventStatisticValues;
 }
\ No newline at end of file
