@@ -34,12 +34,16 @@ import dr.inference.model.MatrixParameter;
 import dr.inference.model.Parameter;
 import dr.inference.model.Variable;
 import dr.math.MathUtils;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
 import no.uib.cipr.matrix.DenseVector;
 import no.uib.cipr.matrix.NotConvergedException;
 import no.uib.cipr.matrix.SymmTridiagEVD;
 import no.uib.cipr.matrix.SymmTridiagMatrix;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 
 /**
@@ -51,7 +55,7 @@ import java.util.List;
  * @author Marc Suchard
  * @version $Id: GMRFSkylineLikelihood.java,v 1.3 2007/03/20 22:40:04 msuchard Exp $
  */
-public class GMRFSkyrideLikelihood extends OldAbstractCoalescentLikelihood implements CoalescentIntervalProvider {
+public class GMRFSkyrideLikelihood extends OldAbstractCoalescentLikelihood implements CoalescentIntervalProvider, Citable {
 
     // PUBLIC STUFF
 
@@ -358,12 +362,20 @@ public class GMRFSkyrideLikelihood extends OldAbstractCoalescentLikelihood imple
         return coalescentIntervals[i];
     }
 
-    public int getCoalescentIntervalLineageCount(int i) {
+    /*public int getCoalescentIntervalLineageCount(int i) {
         throw new RuntimeException("Not yet implemented");
     }
 
     public IntervalType getCoalescentIntervalType(int i) {
-        throw new RuntimeException("Not yet implemented");
+        throw new RuntimeException("getCoalescentIntervalType(int i) in GMRFSkyrideLikelihood not yet implemented");
+    }*/
+
+    public int getNumberOfCoalescentEvents() {
+        return tree.getExternalNodeCount() - 1;
+    }
+
+    public double getCoalescentEventsStatisticValue(int i) {
+        return sufficientStatistics[i];
     }
 
     public double[] getCoalescentIntervalHeights() {
@@ -464,27 +476,27 @@ public class GMRFSkyrideLikelihood extends OldAbstractCoalescentLikelihood imple
     }
 
 
-    public static double logGeneralizedDeterminant(SymmTridiagMatrix X) {
-        //Set up the eigenvalue solver
-        SymmTridiagEVD eigen = new SymmTridiagEVD(X.numRows(), false);
-        //Solve for the eigenvalues
-        try {
-            eigen.factor(X);
-        } catch (NotConvergedException e) {
-            throw new RuntimeException("Not converged error in generalized determinate calculation.\n" + e.getMessage());
-        }
-
-        //Get the eigenvalues
-        double[] x = eigen.getEigenvalues();
-
-        double a = 0;
-        for (double d : x) {
-            if (d > 0.00001)
-                a += Math.log(d);
-        }
-
-        return a;
-    }
+//    public static double logGeneralizedDeterminant(SymmTridiagMatrix X) {
+//        //Set up the eigenvalue solver
+//        SymmTridiagEVD eigen = new SymmTridiagEVD(X.numRows(), false);
+//        //Solve for the eigenvalues
+//        try {
+//            eigen.factor(X);
+//        } catch (NotConvergedException e) {
+//            throw new RuntimeException("Not converged error in generalized determinate calculation.\n" + e.getMessage());
+//        }
+//
+//        //Get the eigenvalues
+//        double[] x = eigen.getEigenvalues();
+//
+//        double a = 0;
+//        for (double d : x) {
+//            if (d > 0.00001)
+//                a += Math.log(d);
+//        }
+//
+//        return a;
+//    }
 
 
     public Parameter getPrecisionParameter() {
@@ -528,9 +540,33 @@ public class GMRFSkyrideLikelihood extends OldAbstractCoalescentLikelihood imple
 
     }
 
-    // ****************************************************************
-    // Private and protected stuff
-    // ****************************************************************
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TREE_PRIORS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Skyride coalescent";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("VN", "Minin"),
+                    new Author("EW", "Bloomquist"),
+                    new Author("MA", "Suchard")
+            },
+            "Smooth skyride through a rough skyline: Bayesian coalescent-based inference of population dynamics",
+            2008,
+            "Mol Biol Evol",
+            25, 1459, 1471,
+            "10.1093/molbev/msn090"
+    );
 }
 
 /*
