@@ -36,6 +36,7 @@ import dr.inference.loggers.NumberColumn;
 import dr.inference.model.*;
 import dr.math.distributions.MultivariateDistribution;
 import dr.math.distributions.MultivariateNormalDistribution;
+import dr.stats.DiscreteStatistics;
 import dr.util.Author;
 import dr.util.Citable;
 import dr.util.Citation;
@@ -44,8 +45,7 @@ import dr.xml.*;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import java.util.ArrayList;
-import java.util.List;
+import java.util.*;
 import java.util.logging.Logger;
 
 /**
@@ -67,6 +67,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
     public static final String SUBSTITUTIONS = "substitutions";
     public static final String SAMPLING_DENSITY = "samplingDensity";
     public static final String INTEGRATE = "integrateInternalTraits";
+    public static final String STANDARDIZE_TRAITS = "standardizeTraits";
     public static final String RECIPROCAL_RATES = "reciprocalRates";
     public static final String PRIOR_SAMPLE_SIZE = "priorSampleSize";
     public static final String RANDOM_SAMPLE = "randomSample";
@@ -78,21 +79,21 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
     public static final String STRENGTH_OF_SELECTION = "strengthOfSelection";
     public static final String OPTIMAL_TRAITS = "optimalTraits";
 
-    public AbstractMultivariateTraitLikelihood(String traitName,
-                                               MultivariateTraitTree treeModel,
-                                               MultivariateDiffusionModel diffusionModel,
-                                               CompoundParameter traitParameter,
-                                               List<Integer> missingIndices,
-                                               boolean cacheBranches,
-                                               boolean scaleByTime,
-                                               boolean useTreeLength,
-                                               BranchRateModel rateModel,
-                                               Model samplingDensity,
-                                               boolean reportAsMultivariate,
-                                               boolean reciprocalRates) {
-        this(traitName, treeModel, diffusionModel, traitParameter, null, missingIndices, cacheBranches,
-                scaleByTime, useTreeLength, rateModel, null, samplingDensity, reportAsMultivariate, reciprocalRates);
-    }
+//    public AbstractMultivariateTraitLikelihood(String traitName,
+//                                               MultivariateTraitTree treeModel,
+//                                               MultivariateDiffusionModel diffusionModel,
+//                                               CompoundParameter traitParameter,
+//                                               List<Integer> missingIndices,
+//                                               boolean cacheBranches,
+//                                               boolean scaleByTime,
+//                                               boolean useTreeLength,
+//                                               BranchRateModel rateModel,
+//                                               Model samplingDensity,
+//                                               boolean reportAsMultivariate,
+//                                               boolean reciprocalRates) {
+//        this(traitName, treeModel, diffusionModel, traitParameter, null, missingIndices, cacheBranches,
+//                scaleByTime, useTreeLength, rateModel, null, samplingDensity, reportAsMultivariate, reciprocalRates);
+//    }
 
     public AbstractMultivariateTraitLikelihood(String traitName,
                                                MultivariateTraitTree treeModel,
@@ -105,6 +106,8 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                                                boolean useTreeLength,
                                                BranchRateModel rateModel,
                                                List<BranchRateModel> driftModels,
+                                               List<BranchRateModel> optimalValues,
+                                               BranchRateModel strengthOfSelection,
                                                Model samplingDensity,
                                                boolean reportAsMultivariate,
                                                boolean reciprocalRates) {
@@ -115,6 +118,8 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         this.treeModel = treeModel;
         this.branchRateModel = rateModel;
         this.driftModels = driftModels;
+        this.optimalValues = optimalValues;
+        this.strengthOfSelection = strengthOfSelection;
         this.diffusionModel = diffusionModel;
         this.traitParameter = traitParameter;
         this.missingIndices = missingIndices;
@@ -137,79 +142,6 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
             }
         }
 
-        if (samplingDensity != null) {
-            addModel(samplingDensity);
-        }
-
-        if (traitParameter != null)
-            addVariable(traitParameter);
-
-        this.reportAsMultivariate = reportAsMultivariate;
-
-        this.cacheBranches = cacheBranches;
-        if (cacheBranches) {
-            cachedLogLikelihoods = new double[treeModel.getNodeCount()];
-            storedCachedLogLikelihood = new double[treeModel.getNodeCount()];
-            validLogLikelihoods = new boolean[treeModel.getNodeCount()];
-            storedValidLogLikelihoods = new boolean[treeModel.getNodeCount()];
-        }
-
-        this.scaleByTime = scaleByTime;
-        this.useTreeLength = useTreeLength;
-        this.reciprocalRates = reciprocalRates;
-
-        dimTrait = diffusionModel.getPrecisionmatrix().length;
-        dim = traitParameter != null ? traitParameter.getParameter(0).getDimension() : 0;
-        numData = dim / dimTrait;
-
-        if (dim % dimTrait != 0)
-            throw new RuntimeException("dim is not divisible by dimTrait");
-
-        recalculateTreeLength();
-        printInformtion();
-
-    }
-
-    public AbstractMultivariateTraitLikelihood(String traitName,
-                                               MultivariateTraitTree treeModel,
-                                               MultivariateDiffusionModel diffusionModel,
-                                               CompoundParameter traitParameter,
-                                               Parameter deltaParameter,
-                                               List<Integer> missingIndices,
-                                               boolean cacheBranches,
-                                               boolean scaleByTime,
-                                               boolean useTreeLength,
-                                               BranchRateModel rateModel,
-                                               List<BranchRateModel> optimalValues,
-                                               BranchRateModel strengthOfSelection,
-                                               Model samplingDensity,
-                                               boolean reportAsMultivariate,
-                                               boolean reciprocalRates) {
-
-        super(TRAIT_LIKELIHOOD);
-
-        this.traitName = traitName;
-        this.treeModel = treeModel;
-        this.branchRateModel = rateModel;
-        this.optimalValues = optimalValues;
-        this.strengthOfSelection = strengthOfSelection;
-        this.diffusionModel = diffusionModel;
-        this.traitParameter = traitParameter;
-        this.missingIndices = missingIndices;
-        addModel(treeModel);
-        addModel(diffusionModel);
-
-        this.deltaParameter = deltaParameter;
-        if (deltaParameter != null) {
-            addVariable(deltaParameter);
-        }
-
-
-        if (rateModel != null) {
-            hasBranchRateModel = true;
-            addModel(rateModel);
-        }
-
         if (optimalValues != null) {
             for (BranchRateModel optVal : optimalValues) {
                 addModel(optVal);
@@ -253,6 +185,89 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
 
     }
 
+//    public AbstractMultivariateTraitLikelihood(String traitName,
+//                                               MultivariateTraitTree treeModel,
+//                                               MultivariateDiffusionModel diffusionModel,
+//                                               CompoundParameter traitParameter,
+//                                               Parameter deltaParameter,
+//                                               List<Integer> missingIndices,
+//                                               boolean cacheBranches,
+//                                               boolean scaleByTime,
+//                                               boolean useTreeLength,
+//                                               BranchRateModel rateModel,
+//                                               List<BranchRateModel> optimalValues,
+//                                               BranchRateModel strengthOfSelection,
+//                                               Model samplingDensity,
+//                                               boolean reportAsMultivariate,
+//                                               boolean reciprocalRates) {
+//
+//        super(TRAIT_LIKELIHOOD);
+//
+//        this.traitName = traitName;
+//        this.treeModel = treeModel;
+//        this.branchRateModel = rateModel;
+//        this.optimalValues = optimalValues;
+//        this.strengthOfSelection = strengthOfSelection;
+//        this.diffusionModel = diffusionModel;
+//        this.traitParameter = traitParameter;
+//        this.missingIndices = missingIndices;
+//        addModel(treeModel);
+//        addModel(diffusionModel);
+//
+//        this.deltaParameter = deltaParameter;
+//        if (deltaParameter != null) {
+//            addVariable(deltaParameter);
+//        }
+//
+//
+//        if (rateModel != null) {
+//            hasBranchRateModel = true;
+//            addModel(rateModel);
+//        }
+//
+//        if (optimalValues != null) {
+//            for (BranchRateModel optVal : optimalValues) {
+//                addModel(optVal);
+//            }
+//        }
+//
+//        if (strengthOfSelection != null) {
+//            addModel(strengthOfSelection);
+//        }
+//
+//        if (samplingDensity != null) {
+//            addModel(samplingDensity);
+//        }
+//
+//        if (traitParameter != null)
+//            addVariable(traitParameter);
+//
+//        this.reportAsMultivariate = reportAsMultivariate;
+//
+//        this.cacheBranches = cacheBranches;
+//        if (cacheBranches) {
+//            cachedLogLikelihoods = new double[treeModel.getNodeCount()];
+//            storedCachedLogLikelihood = new double[treeModel.getNodeCount()];
+//            validLogLikelihoods = new boolean[treeModel.getNodeCount()];
+//            storedValidLogLikelihoods = new boolean[treeModel.getNodeCount()];
+//        }
+//
+//        this.scaleByTime = scaleByTime;
+//        this.useTreeLength = useTreeLength;
+//        this.reciprocalRates = reciprocalRates;
+//
+//        dimTrait = diffusionModel.getPrecisionmatrix().length;
+//        dim = traitParameter != null ? traitParameter.getParameter(0).getDimension() : 0;
+//        numData = dim / dimTrait;
+//
+//        if (dim % dimTrait != 0)
+//            throw new RuntimeException("dim is not divisible by dimTrait");
+//
+//        recalculateTreeLength();
+//        printInformtion();
+//
+//    }
+
 
     protected void printInformtion() {
         StringBuffer sb = new StringBuffer("Creating multivariate diffusion model:\n");
@@ -279,11 +294,22 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         Logger.getLogger("dr.evomodel").info(sb.toString());
     }
 
-    private static Citable TraitAscertainmentCitation = new Citable() {//} implements Citable {
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TRAIT_MODELS;
+    }
 
-        public List<Citation> getCitations() {
-            List<Citation> list = new ArrayList<Citation>();
-            list.add(
+    @Override
+    public String getDescription() {
+        return "Multivariate Diffusion model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        List<Citation> citations = new ArrayList<Citation>();
+        citations.add(CommonCitations.LEMEY_2010_PHYLOGEOGRAPHY);
+        if (doAscertainmentCorrect) {
+            citations.add(
                     new Citation(
                             new Author[]{
                                     new Author("MA", "Suchard"),
@@ -294,15 +320,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                             Citation.Status.IN_PREPARATION
                     )
             );
-            return list;
         }
-    };
-
-    public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                CommonCitations.LEMEY_2010
-        );
         return citations;
     }
 
@@ -321,8 +339,6 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
         StringBuilder sb = new StringBuilder("Enabling ascertainment correction for multivariate trait model: ");
         sb.append(getId()).append("\n");
         sb.append("\tTaxon: ").append(taxon.getId()).append("\n");
-        sb.append("\tPlease cite:\n");
-        sb.append(Citable.Utils.getCitationString(TraitAscertainmentCitation));
         Logger.getLogger("dr.evomodel").info(sb.toString());
     }
 
@@ -725,6 +741,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
             boolean scaleByTime = xo.getAttribute(SCALE_BY_TIME, false);
             boolean reciprocalRates = xo.getAttribute(RECIPROCAL_RATES, false);
             boolean reportAsMultivariate = xo.getAttribute(REPORT_MULTIVARIATE, true);
+            boolean standardizeTraits = xo.getAttribute(STANDARDIZE_TRAITS, false);
 
             BranchRateModel rateModel = (BranchRateModel) xo.getChild(BranchRateModel.class);
 
@@ -786,6 +803,44 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                 XMLObject cxo = xo.getChild("delta");
                 deltaParameter = (Parameter) cxo.getChild(Parameter.class);
             }
+
+
+            if (standardizeTraits) {
+                //                standardize(traitParameter);
+                //                dimTrait = diffusionModel.getPrecisionmatrix().length;
+                //                        dim = traitParameter != null ? traitParameter.getParameter(0).getDimension() : 0;
+                //                        numData = dim / dimTrait;
+
+                //                System.err.println(traitParameter.getDimension());
+                //                System.err.println(traitParameter.getParameterCount());
+                //                System.err.println(traitParameter.getParameter(0).getDimension());
+                //                System.exit(-1);
+                int numTraits = traitParameter.getParameter(0).getDimension();
+                int numObservations = traitParameter.getParameterCount();
+
+                StringBuilder sb = new StringBuilder();
+                sb.append("Traits have been standardized.  Use following to transform values back to original scale.\n");
+                for (int trait = 0; trait < numTraits; ++trait) {
+                    double[] values = new double[numObservations];
+                    for (int obs = 0; obs < numObservations; ++obs) {
+                        values[obs] = traitParameter.getParameter(obs).getParameterValue(trait);
+                    }
+
+                    double traitMean = DiscreteStatistics.mean(values);
+                    double traitSD = Math.sqrt(DiscreteStatistics.variance(values, traitMean));
+
+                    sb.append("\tDimension " + (trait + 1) + ": multiply by " + traitSD + " then add " + traitMean + "\n");
+
+                    for (int obs = 0; obs < numObservations; ++obs) {
+                        traitParameter.getParameter(obs).setParameterValue(trait,
+                                (values[obs] - traitMean) / traitSD);
+                    }
+                }
+
+                Logger.getLogger("dr.evomodel").info(sb.toString());
+
+            }
+            
             AbstractMultivariateTraitLikelihood like;
 
             if (integrate) {
@@ -841,18 +896,24 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
                             if (strengthOfSelection == null) {
                                 like = new FullyConjugateMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
                                         traitParameter, deltaParameter, missingIndices, cacheBranches,
-                                        scaleByTime, useTreeLength, rateModel, samplingDensity, reportAsMultivariate,
+                                        scaleByTime, useTreeLength,
+                                        rateModel, null, null, null,
+                                        samplingDensity, reportAsMultivariate,
                                         mean, pseudoObservations, reciprocalRates);
                             } else {
                                 like = new FullyConjugateMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
                                         traitParameter, deltaParameter, missingIndices, cacheBranches,
-                                        scaleByTime, useTreeLength, rateModel, optimalValues, strengthOfSelection, samplingDensity, reportAsMultivariate,
+                                        scaleByTime, useTreeLength,
+                                        rateModel, null, optimalValues, strengthOfSelection,
+                                        samplingDensity, reportAsMultivariate,
                                         mean, pseudoObservations, reciprocalRates);
                             }
                         } else {
                             like = new FullyConjugateMultivariateTraitLikelihood(traitName, treeModel, diffusionModel,
                                     traitParameter, deltaParameter, missingIndices, cacheBranches,
-                                    scaleByTime, useTreeLength, rateModel, driftModels, samplingDensity, reportAsMultivariate,
+                                    scaleByTime, useTreeLength,
+                                    rateModel, driftModels, null, null,
+                                    samplingDensity, reportAsMultivariate,
                                     mean, pseudoObservations, reciprocalRates);
                         }
                     }
@@ -880,7 +941,7 @@ public abstract class AbstractMultivariateTraitLikelihood extends AbstractModelL
             }
 
             if (!xo.hasAttribute(TreeTraitParserUtilities.ALLOW_IDENTICAL) &&
-                    utilities.hasIdenticalTraits(traitParameter, diffusionModel.getPrecisionmatrix().length)) {
+                    utilities.hasIdenticalTraits(traitParameter, missingIndices, diffusionModel.getPrecisionmatrix().length)) {
                 throw new XMLParseException("For multivariate trait analyses, all trait values should be unique.\n" +
                         "Check data or add random noise using 'jitter' option.");
             }
