@@ -42,9 +42,9 @@ import dr.math.matrixAlgebra.SymmetricMatrix;
 import dr.math.matrixAlgebra.Vector;
 import dr.util.Author;
 import dr.util.Citation;
+import dr.util.CommonCitations;
 
-import java.util.Arrays;
-import java.util.List;
+import java.util.*;
 
 /**
  * A multivariate trait likelihood that analytically integrates out the unobserved trait values at all internal
@@ -56,36 +56,36 @@ public abstract class IntegratedMultivariateTraitLikelihood extends AbstractMult
 
     public static final double LOG_SQRT_2_PI = 0.5 * Math.log(2 * Math.PI);
 
-    public IntegratedMultivariateTraitLikelihood(String traitName,
-                                                 MultivariateTraitTree treeModel,
-                                                 MultivariateDiffusionModel diffusionModel,
-                                                 CompoundParameter traitParameter,
-                                                 List<Integer> missingIndices,
-                                                 boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
-                                                 BranchRateModel rateModel, Model samplingDensity,
-                                                 boolean reportAsMultivariate,
-                                                 boolean reciprocalRates) {
-
-        this(traitName, treeModel, diffusionModel, traitParameter, null, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, samplingDensity, reportAsMultivariate, reciprocalRates);
-    }
-
-    public IntegratedMultivariateTraitLikelihood(String traitName,
-                                                 MultivariateTraitTree treeModel,
-                                                 MultivariateDiffusionModel diffusionModel,
-                                                 CompoundParameter traitParameter,
-                                                 Parameter deltaParameter,
-                                                 List<Integer> missingIndices,
-                                                 boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
-                                                 BranchRateModel rateModel, Model samplingDensity,
-                                                 boolean reportAsMultivariate,
-                                                 boolean reciprocalRates) {
-        this(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches,
-                scaleByTime, useTreeLength, rateModel, null, samplingDensity, reportAsMultivariate, reciprocalRates);
-    }
+//    public IntegratedMultivariateTraitLikelihood(String traitName,
+//                                                 MultivariateTraitTree treeModel,
+//                                                 MultivariateDiffusionModel diffusionModel,
+//                                                 CompoundParameter traitParameter,
+//                                                 List<Integer> missingIndices,
+//                                                 boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
+//                                                 BranchRateModel rateModel, Model samplingDensity,
+//                                                 boolean reportAsMultivariate,
+//                                                 boolean reciprocalRates) {
+//
+//        this(traitName, treeModel, diffusionModel, traitParameter, null, missingIndices, cacheBranches, scaleByTime,
+//                useTreeLength, rateModel, samplingDensity, reportAsMultivariate, reciprocalRates);
+//    }
+//
+//    public IntegratedMultivariateTraitLikelihood(String traitName,
+//                                                 MultivariateTraitTree treeModel,
+//                                                 MultivariateDiffusionModel diffusionModel,
+//                                                 CompoundParameter traitParameter,
+//                                                 Parameter deltaParameter,
+//                                                 List<Integer> missingIndices,
+//                                                 boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
+//                                                 BranchRateModel rateModel, Model samplingDensity,
+//                                                 boolean reportAsMultivariate,
+//                                                 boolean reciprocalRates) {
+//        this(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches,
+//                scaleByTime, useTreeLength, rateModel, null, samplingDensity, reportAsMultivariate, reciprocalRates);
+//    }
 
 
-    private final CacheHelper cacheHelper;
+    protected final CacheHelper cacheHelper;
 
     public IntegratedMultivariateTraitLikelihood(String traitName,
                                                  MultivariateTraitTree treeModel,
@@ -96,54 +96,6 @@ public abstract class IntegratedMultivariateTraitLikelihood extends AbstractMult
                                                  boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
                                                  BranchRateModel rateModel,
                                                  List<BranchRateModel> driftModels,
-                                                 Model samplingDensity,
-                                                 boolean reportAsMultivariate,
-                                                 boolean reciprocalRates) {
-
-        super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, driftModels, samplingDensity, reportAsMultivariate, reciprocalRates);
-
-
-        // Delegate caches to helper
-        meanCache = new double[dim * treeModel.getNodeCount()];
-        if (driftModels != null) {
-            cacheHelper = new DriftCacheHelper(dim * treeModel.getNodeCount(), cacheBranches); // new DriftCacheHelper ....
-        } else {
-            cacheHelper = new CacheHelper(dim * treeModel.getNodeCount(), cacheBranches);
-        }
-
-        drawnStates = new double[dim * treeModel.getNodeCount()];
-        upperPrecisionCache = new double[treeModel.getNodeCount()];
-        lowerPrecisionCache = new double[treeModel.getNodeCount()];
-        logRemainderDensityCache = new double[treeModel.getNodeCount()];
-
-        if (cacheBranches) {
-            storedMeanCache = new double[dim * treeModel.getNodeCount()];
-            storedUpperPrecisionCache = new double[treeModel.getNodeCount()];
-            storedLowerPrecisionCache = new double[treeModel.getNodeCount()];
-            storedLogRemainderDensityCache = new double[treeModel.getNodeCount()];
-        }
-
-        // Set up reusable temporary storage
-        Ay = new double[dimTrait];
-        tmpM = new double[dimTrait][dimTrait];
-        tmp2 = new double[dimTrait];
-
-        zeroDimVector = new double[dim];
-
-        missingTraits = new MissingTraits.CompletelyMissing(treeModel, missingIndices, dim);
-        setTipDataValuesForAllNodes();
-
-    }
-
-    public IntegratedMultivariateTraitLikelihood(String traitName,
-                                                 MultivariateTraitTree treeModel,
-                                                 MultivariateDiffusionModel diffusionModel,
-                                                 CompoundParameter traitParameter,
-                                                 Parameter deltaParameter,
-                                                 List<Integer> missingIndices,
-                                                 boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
-                                                 BranchRateModel rateModel,
                                                  List<BranchRateModel> optimalValues,
                                                  BranchRateModel strengthOfSelection,
                                                  Model samplingDensity,
@@ -151,18 +103,21 @@ public abstract class IntegratedMultivariateTraitLikelihood extends AbstractMult
                                                  boolean reciprocalRates) {
 
         super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
-                useTreeLength, rateModel, optimalValues, strengthOfSelection, samplingDensity, reportAsMultivariate, reciprocalRates);
+                useTreeLength, rateModel, driftModels,
+                optimalValues, strengthOfSelection,
+                samplingDensity, reportAsMultivariate, reciprocalRates);
+
 
         // Delegate caches to helper
         meanCache = new double[dim * treeModel.getNodeCount()];
-
-        if (optimalValues != null) {
+        if (driftModels != null) {
+            cacheHelper = new DriftCacheHelper(dim * treeModel.getNodeCount(), cacheBranches); // new DriftCacheHelper ....
+        } else if (optimalValues != null) {
             cacheHelper = new OUCacheHelper(dim * treeModel.getNodeCount(), cacheBranches);
         } else {
             cacheHelper = new CacheHelper(dim * treeModel.getNodeCount(), cacheBranches);
         }
 
-
         drawnStates = new double[dim * treeModel.getNodeCount()];
         upperPrecisionCache = new double[treeModel.getNodeCount()];
         lowerPrecisionCache = new double[treeModel.getNodeCount()];
@@ -187,6 +142,57 @@ public abstract class IntegratedMultivariateTraitLikelihood extends AbstractMult
 
     }
 
+//    public IntegratedMultivariateTraitLikelihood(String traitName,
+//                                                 MultivariateTraitTree treeModel,
+//                                                 MultivariateDiffusionModel diffusionModel,
+//                                                 CompoundParameter traitParameter,
+//                                                 Parameter deltaParameter,
+//                                                 List<Integer> missingIndices,
+//                                                 boolean cacheBranches, boolean scaleByTime, boolean useTreeLength,
+//                                                 BranchRateModel rateModel,
+//                                                 List<BranchRateModel> optimalValues,
+//                                                 BranchRateModel strengthOfSelection,
+//                                                 Model samplingDensity,
+//                                                 boolean reportAsMultivariate,
+//                                                 boolean reciprocalRates) {
+//
+//        super(traitName, treeModel, diffusionModel, traitParameter, deltaParameter, missingIndices, cacheBranches, scaleByTime,
+//                useTreeLength, rateModel, optimalValues, strengthOfSelection, samplingDensity, reportAsMultivariate, reciprocalRates);
+//
+//        // Delegate caches to helper
+//        meanCache = new double[dim * treeModel.getNodeCount()];
+//
+//        if (optimalValues != null) {
+//            cacheHelper = new OUCacheHelper(dim * treeModel.getNodeCount(), cacheBranches);
+//        } else {
+//            cacheHelper = new CacheHelper(dim * treeModel.getNodeCount(), cacheBranches);
+//        }
+//
+//
+//        drawnStates = new double[dim * treeModel.getNodeCount()];
+//        upperPrecisionCache = new double[treeModel.getNodeCount()];
+//        lowerPrecisionCache = new double[treeModel.getNodeCount()];
+//        logRemainderDensityCache = new double[treeModel.getNodeCount()];
+//
+//        if (cacheBranches) {
+//            storedMeanCache = new double[dim * treeModel.getNodeCount()];
+//            storedUpperPrecisionCache = new double[treeModel.getNodeCount()];
+//            storedLowerPrecisionCache = new double[treeModel.getNodeCount()];
+//            storedLogRemainderDensityCache = new double[treeModel.getNodeCount()];
+//        }
+//
+//        // Set up reusable temporary storage
+//        Ay = new double[dimTrait];
+//        tmpM = new double[dimTrait][dimTrait];
+//        tmp2 = new double[dimTrait];
+//
+//        zeroDimVector = new double[dim];
+//
+//        missingTraits = new MissingTraits.CompletelyMissing(treeModel, missingIndices, dim);
+//        setTipDataValuesForAllNodes();
+//
+//    }
+
 
     private void setTipDataValuesForAllNodes() {
         for (int i = 0; i < treeModel.getExternalNodeCount(); i++) {
@@ -235,33 +241,40 @@ public abstract class IntegratedMultivariateTraitLikelihood extends AbstractMult
         return "\tSample internal node traits: false\n";
     }
 
-    public List<Citation> getCitations() {
-        List<Citation> citations = super.getCitations();
-        citations.add(
-                new Citation(
-                        new Author[]{
-                                new Author("OG", "Pybus"),
-                                new Author("MA", "Suchard"),
-                                new Author("P", "Lemey"),
-                                new Author("F", "Bernadin"),
-                                new Author("A", "Rambaut"),
-                                new Author("FW", "Crawford"),
-                                new Author("RR", "Gray"),
-                                new Author("N", "Arinaminpathy"),
-                                new Author("S", "Stramer"),
-                                new Author("MP", "Busch"),
-                                new Author("E", "Delwart")
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TRAIT_MODELS;
+    }
 
-                        },
-                        "Unifying the spatial epidemiology and evolution of emerging epidemics",
-                        2012,
-                        "Proceedings of the National Academy of Sciences",
-                        109,
-                        15066, 15071,
-                        Citation.Status.PUBLISHED
-                )
-        );
-        return citations;
+    @Override
+    public String getDescription() {
+        return super.getDescription() + " (first citation) with efficiently integrated internal traits (second citation)";
+    }
+
+    public List<Citation> getCitations() {
+        List<Citation> rtn = super.getCitations();
+        rtn.add(new Citation(
+                new Author[] {
+                        new Author("OG", "Pybus"),
+                        new Author("MA", "Suchard"),
+                        new Author("P", "Lemey"),
+                        new Author("F", "Bernadin"),
+                        new Author("A", "Rambaut"),
+                        new Author("FW", "Crawford"),
+                        new Author("RR", "Gray"),
+                        new Author("N", "Arinaminpathy"),
+                        new Author("S", "Stramer"),
+                        new Author("MP", "Busch"),
+                        new Author("E", "Delwart")
+                },
+                "Unifying the spatial epidemiology and evolution of emerging epidemics",
+                2012,
+                "Proceedings of the National Academy of Sciences",
+                109,
+                15066, 15071,
+                Citation.Status.PUBLISHED
+        ));
+        return rtn;
     }
 
     public double getLogDataLikelihood() {
@@ -609,8 +622,8 @@ public abstract class IntegratedMultivariateTraitLikelihood extends AbstractMult
 
                 for (int i = 0; i < dimTrait; ++i) {
                     System.err.println("\t"
-                                    + cacheHelper.getCorrectedMeanCache()[childOffset0 + 0 * dimTrait + i] + " "
-                                    + cacheHelper.getCorrectedMeanCache()[childOffset1 + 0 * dimTrait + i]
+                            + cacheHelper.getCorrectedMeanCache()[childOffset0 + 0 * dimTrait + i] + " "
+                            + cacheHelper.getCorrectedMeanCache()[childOffset1 + 0 * dimTrait + i]
                     );
                 }
                 System.exit(-1);
