@@ -1,7 +1,7 @@
 /*
  * IntervalLatentLiabilityLikelihood.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -35,7 +35,9 @@ import dr.util.CommonCitations;
 import dr.xml.*;
 
 import java.util.ArrayList;
+import java.util.LinkedHashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.logging.Logger;
 
 
@@ -282,11 +284,20 @@ public class IntervalLatentLiabilityLikelihood extends AbstractModelLikelihood i
         }
     };
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.TRAIT_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Intervaled latent liability model";
+    }
+
+    @Override
     public List<Citation> getCitations() {
         List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                CommonCitations.SUCHARD_2012_LATENT
-        );
+        citations.add(CommonCitations.CYBIS_2015_ASSESSING);
         return citations;
     }
 
