@@ -1,5 +1,31 @@
+/*
+ * CategoryOutbreak.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 package dr.evomodel.epidemiology.casetocase;
 
+import dr.evolution.util.Date;
 import dr.evolution.util.Taxa;
 import dr.evolution.util.Taxon;
 import dr.evomodel.epidemiology.casetocase.periodpriors.AbstractPeriodPriorDistribution;
@@ -34,6 +60,7 @@ public class CategoryOutbreak extends AbstractOutbreak {
     private final HashSet<String> infectiousCategories;
     private final HashMap<String, Parameter> latentMap;
     private final HashMap<String, AbstractPeriodPriorDistribution> infectiousMap;
+    private final HashMap<AbstractCase, Double> weightMap;
     private double[][] distances;
 
 
@@ -52,23 +79,26 @@ public class CategoryOutbreak extends AbstractOutbreak {
         for(Parameter hyperprior : latentMap.values()){
             addVariable(hyperprior);
         }
+        weightMap = new HashMap<AbstractCase, Double>();
     }
 
 
-    private void addCase(String caseID, double examTime, double cullTime, Parameter coords,
-                         Parameter infectionPosition, Taxa associatedTaxa, String infectiousCategory,
-                         String latentCategory){
+    private void addCase(String caseID, double endTime, Parameter coords,
+                         Parameter infectionPosition, Taxa associatedTaxa, double indexPriorWeight,
+                         String infectiousCategory, String latentCategory){
         CategoryCase thisCase;
 
         if(latentCategory==null){
-            thisCase =  new CategoryCase(caseID, examTime, cullTime, coords, infectionPosition, associatedTaxa,
-                    infectiousCategory);
+            thisCase =  new CategoryCase(caseID, endTime, coords, infectionPosition, associatedTaxa,
+                    indexPriorWeight, infectiousCategory);
         } else {
             thisCase =
-                    new CategoryCase(caseID, examTime, cullTime, coords, infectionPosition, associatedTaxa,
-                            infectiousCategory, latentCategory);
+                    new CategoryCase(caseID, endTime, coords, infectionPosition, associatedTaxa,
+                            indexPriorWeight, infectiousCategory, latentCategory);
             latentCategories.add(latentCategory);
         }
+        weightMap.put(thisCase, indexPriorWeight);
+
         infectiousCategories.add(infectiousCategory);
         cases.add(thisCase);
         infectedSize++;
@@ -76,8 +106,7 @@ public class CategoryOutbreak extends AbstractOutbreak {
     }
 
     private void addNoninfectedCase(String caseID, Parameter coords){
-        CategoryCase thisCase = new CategoryCase(caseID, Double.POSITIVE_INFINITY, Double.POSITIVE_INFINITY, coords,
-                null, null, null);
+        CategoryCase thisCase = new CategoryCase(caseID, Double.POSITIVE_INFINITY, coords, null, null, 0.0, null);
         thisCase.setEverInfected(false);
 
         cases.add(thisCase);
@@ -85,7 +114,9 @@ public class CategoryOutbreak extends AbstractOutbreak {
     }
 
 
-
+    public HashMap<AbstractCase, Double> getWeightMap(){
+        return weightMap;
+    }
 
     public HashSet<String> getLatentCategories(){
         return latentCategories;
@@ -183,46 +214,61 @@ public class CategoryOutbreak extends AbstractOutbreak {
         private String infectiousCategory;
         private String latentCategory;
         private Parameter coords;
+        private double indexPriorWeight;
+        private final ArrayList<Date> examinationTimes;
 
-
-        private CategoryCase(String name, String caseID, double examTime, double cullTime, Parameter coords,
-                             Parameter infectionBranchPosition, Taxa associatedTaxa, String infectiousCategory){
+        private CategoryCase(String name, String caseID, double endTime, Parameter coords,
+                             Parameter infectionBranchPosition, Taxa associatedTaxa, double indexPriorWeight,
+                             String infectiousCategory, String latentCategory){
             super(name);
-            wasEverInfected = true;
+
+            wasEverInfected = associatedTaxa != null;
+
             this.caseID = caseID;
             this.infectiousCategory = infectiousCategory;
             this.infectionBranchPosition = infectionBranchPosition;
             if(infectionBranchPosition!=null) {
                 addVariable(infectionBranchPosition);
             }
-            this.examTime = examTime;
-            endOfInfectiousTime = cullTime;
+            endOfInfectiousTime = endTime;
             this.associatedTaxa = associatedTaxa;
             this.coords = coords;
-            latentCategory = null;
-        }
-
-
-        private CategoryCase(String name, String caseID, double examTime, double cullTime, Parameter coords,
-                             Parameter infectionBranchPosition, Taxa associatedTaxa, String infectiousCategory,
-                             String latentCategory){
-            this(name, caseID, examTime, cullTime, coords, infectionBranchPosition, associatedTaxa, infectiousCategory);
+            this.indexPriorWeight = indexPriorWeight;
             this.latentCategory = latentCategory;
+
+            examinationTimes = new ArrayList<Date>();
+
+            if(wasEverInfected) {
+                for (Taxon taxon : associatedTaxa) {
+                    examinationTimes.add(taxon.getDate());
+                }
+            }
+
         }
 
-
-        private CategoryCase(String caseID, double examTime, double cullTime, Parameter coords,
-                             Parameter infectionBranchPosition, Taxa associatedTaxa, String infectiousCategory){
-            this(CATEGORY_CASE, caseID, examTime, cullTime, coords, infectionBranchPosition, associatedTaxa,
-                    infectiousCategory);
-        }
-
-
-        private CategoryCase(String caseID, double examTime, double cullTime, Parameter coords,
+        private CategoryCase(String name, String caseID, double endTime, Parameter coords,
                              Parameter infectionBranchPosition, Taxa associatedTaxa,
+                             String infectiousCategory){
+            this(name, caseID, endTime, coords, infectionBranchPosition, associatedTaxa, 1.0,
+                    infectiousCategory, null);
+
+        }
+
+
+
+        private CategoryCase(String caseID, double endTime, Parameter coords,
+                             Parameter infectionBranchPosition, Taxa associatedTaxa, double indexPriorWeight,
+                             String infectiousCategory){
+            this(CATEGORY_CASE, caseID, endTime, coords, infectionBranchPosition, associatedTaxa,
+                    indexPriorWeight, infectiousCategory, null);
+        }
+
+
+        private CategoryCase(String caseID, double endTime, Parameter coords,
+                             Parameter infectionBranchPosition, Taxa associatedTaxa, double indexPriorWeight,
                              String infectiousCategory, String latentCategory){
-            this(CATEGORY_CASE, caseID, examTime, cullTime, coords, infectionBranchPosition, associatedTaxa,
-                    infectiousCategory, latentCategory);
+            this(CATEGORY_CASE, caseID, endTime, coords, infectionBranchPosition, associatedTaxa,
+                    indexPriorWeight, infectiousCategory, latentCategory);
         }
 
         //noninfected susceptible constructor
@@ -235,14 +281,14 @@ public class CategoryOutbreak extends AbstractOutbreak {
             return infectiousCategory;
         }
 
+        public double getIndexPriorWeight() { return indexPriorWeight;}
 
-
-        public boolean culledYet(double time) {
+        public boolean noninfectiousYet(double time) {
             return time>endOfInfectiousTime;
         }
 
-        public boolean examinedYet(double time) {
-            return time>examTime;
+        public ArrayList<Date> getExaminationTimes(){
+            return examinationTimes;
         }
 
         protected void handleModelChangedEvent(Model model, Object object, int index) {
@@ -282,14 +328,14 @@ public class CategoryOutbreak extends AbstractOutbreak {
 
         //for the cases
 
-        public static final String CASE_ID = "caseID";
-        public static final String CULL_TIME = "cullTime";
-        public static final String EXAMINATION_TIME = "examTime";
+        public static final String CASE_ID = "hostID";
+        public static final String END_TIME = "endTime";
         public static final String COORDINATES = "spatialCoordinates";
         public static final String INFECTION_TIME_BRANCH_POSITION = "infectionTimeBranchPosition";
         public static final String LATENT_CATEGORY = "latentCategory";
         public static final String INFECTIOUS_CATEGORY = "infectiousCategory";
         public static final String WAS_EVER_INFECTED = "wasEverInfected";
+        public static final String INDEX_PRIOR_WEIGHT = "indexPriorWeight";
 
         //for the normal-gamma priors
 
@@ -389,22 +435,27 @@ public class CategoryOutbreak extends AbstractOutbreak {
             if(wasEverInfected) {
 
                 if(!xo.hasAttribute(INFECTIOUS_CATEGORY)
-                        || !xo.hasAttribute(CULL_TIME)
-                        || !xo.hasAttribute(EXAMINATION_TIME)
+                        || !xo.hasAttribute(END_TIME)
                         || !xo.hasChildNamed(INFECTION_TIME_BRANCH_POSITION)){
                     throw new XMLParseException("Case " + farmID + " wasEverInfected but lacks infection-related data");
                 }
 
 
                 String infectiousCategory = (String) xo.getAttribute(INFECTIOUS_CATEGORY);
-                final double cullTime = Double.parseDouble((String) xo.getAttribute(CULL_TIME));
-                final double examTime = Double.parseDouble((String) xo.getAttribute(EXAMINATION_TIME));
+                final double endTime = Double.parseDouble((String) xo.getAttribute(END_TIME));
                 String latentCategory = null;
                 if (xo.hasAttribute(LATENT_CATEGORY)) {
                     latentCategory = (String) xo.getAttribute(LATENT_CATEGORY);
                 } else if (expectLatentPeriods) {
                     throw new XMLParseException("Case " + farmID + " not assigned a latent periods distribution");
                 }
+
+                double indexPriorWeight = 1;
+
+                if(xo.hasAttribute(INDEX_PRIOR_WEIGHT)){
+                    indexPriorWeight = Double.parseDouble((String)xo.getAttribute(INDEX_PRIOR_WEIGHT));
+                }
+
                 final Parameter ibp = (Parameter) xo.getElementFirstChild(INFECTION_TIME_BRANCH_POSITION);
 
 
@@ -414,7 +465,7 @@ public class CategoryOutbreak extends AbstractOutbreak {
                         taxa.addTaxon((Taxon) xo.getChild(i));
                     }
                 }
-                outbreak.addCase(farmID, examTime, cullTime, coords, ibp, taxa, infectiousCategory, latentCategory);
+                outbreak.addCase(farmID, endTime, coords, ibp, taxa, indexPriorWeight, infectiousCategory, latentCategory);
             } else {
                 outbreak.addNoninfectedCase(farmID, coords);
 
@@ -441,15 +492,16 @@ public class CategoryOutbreak extends AbstractOutbreak {
 
         private final XMLSyntaxRule[] caseRules = {
                 AttributeRule.newBooleanRule(WAS_EVER_INFECTED),
-                new StringAttributeRule(CASE_ID, "The unique identifier for this farm"),
-                new StringAttributeRule(CULL_TIME, "The time this farm was culled", true),
-                new StringAttributeRule(EXAMINATION_TIME, "The date this farm was examined", true),
+                new StringAttributeRule(CASE_ID, "The unique identifier for this host"),
+                new StringAttributeRule(END_TIME, "The time of noninfectiousness of this host", true),
                 new ElementRule(Taxon.class, 0, Integer.MAX_VALUE),
                 new ElementRule(INFECTION_TIME_BRANCH_POSITION, Parameter.class, "The exact position on the branch" +
                         " along which the infection of this case occurs that it actually does occur", true),
                 new ElementRule(COORDINATES, Parameter.class, "The spatial coordinates of this case", true),
                 new StringAttributeRule(LATENT_CATEGORY, "The category of latent period", true),
-                new StringAttributeRule(INFECTIOUS_CATEGORY, "The category of infectious period", true)
+                new StringAttributeRule(INFECTIOUS_CATEGORY, "The category of infectious period", true),
+                new StringAttributeRule(INDEX_PRIOR_WEIGHT, "The weight of this case in the prior probabilty for the" +
+                        "index case", true)
         };
 
 
@@ -458,10 +510,10 @@ public class CategoryOutbreak extends AbstractOutbreak {
                 new ElementRule(ProductStatistic.class, 0,2),
                 new ElementRule(CategoryCase.CATEGORY_CASE, caseRules, 1, Integer.MAX_VALUE),
                 new ElementRule(Taxa.class),
-                new ElementRule(INFECTIOUS_PERIOD_PRIOR, AbstractPeriodPriorDistribution.class, "blah", 1,
-                        Integer.MAX_VALUE),
-                new ElementRule(LATENT_PERIODS, Parameter.class, "blah", 0,
-                        Integer.MAX_VALUE),
+                new ElementRule(INFECTIOUS_PERIOD_PRIOR, AbstractPeriodPriorDistribution.class, "A prior " +
+                        "distribution for the length of infectious periods", 1, Integer.MAX_VALUE),
+                new ElementRule(LATENT_PERIODS, Parameter.class, "A prior distribution for the length of latent" +
+                        " periods", 0, Integer.MAX_VALUE),
                 AttributeRule.newBooleanRule(HAS_GEOGRAPHY, true),
                 new ElementRule(DISTANCE_MATRIX, Parameter.class, "A matrix of distances between the cases in this " +
                         "outbreak", true)
