@@ -28,18 +28,15 @@ package dr.evomodel.epidemiology.casetocase.operators;
 import dr.evolution.tree.NodeRef;
 import dr.evolution.tree.Tree;
 import dr.evomodel.epidemiology.casetocase.AbstractCase;
-import dr.evomodel.epidemiology.casetocase.AbstractOutbreak;
 import dr.evomodel.epidemiology.casetocase.BranchMapModel;
 import dr.evomodel.epidemiology.casetocase.CaseToCaseTreeLikelihood;
 import dr.evomodel.operators.AbstractTreeOperator;
 import dr.evomodel.tree.TreeModel;
-import dr.inference.model.Parameter;
 import dr.inference.operators.*;
 import dr.math.MathUtils;
 import dr.xml.*;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 
 /**
@@ -98,16 +95,13 @@ public class TransmissionSubtreeSlideA extends AbstractTreeOperator implements C
     public double doOperation() throws OperatorFailedException {
 
         if(DEBUG){
-            c2cLikelihood.debugOutputTree("beforeTSSA.nex", false);
+            c2cLikelihood.outputTreeToFile("beforeTSSA.nex", false);
         }
 
         BranchMapModel branchMap = c2cLikelihood.getBranchMap();
 
         double logq = 0;
 
-        final NodeRef root = tree.getRoot();
-        final double oldTreeHeight = tree.getNodeHeight(root);
-
         NodeRef i;
 
         // 1. choose a random eligible node
@@ -116,7 +110,7 @@ public class TransmissionSubtreeSlideA extends AbstractTreeOperator implements C
 
         i = eligibleNodes.get(MathUtils.nextInt(eligibleNodes.size()));
 
-        int eligibleNodeCount = eligibleNodes.size();
+        double eligibleNodeCount = eligibleNodes.size();
 
 
         final NodeRef iP = tree.getParent(i);
@@ -350,11 +344,11 @@ public class TransmissionSubtreeSlideA extends AbstractTreeOperator implements C
         if (logq == Double.NEGATIVE_INFINITY) throw new OperatorFailedException("invalid slide");
 
         if (DEBUG){
-            c2cLikelihood.checkPartitions();
-            c2cLikelihood.debugOutputTree("afterTSSA.nex", false);
+            c2cLikelihood.getTreeModel().checkPartitions();
+            c2cLikelihood.outputTreeToFile("afterTSSA.nex", false);
         }
 
-        int reverseEligibleNodeCount = getEligibleNodes(tree, branchMap).size();
+        double reverseEligibleNodeCount = getEligibleNodes(tree, branchMap).size();
 
         logq += Math.log(eligibleNodeCount/reverseEligibleNodeCount);
 
@@ -395,18 +389,14 @@ public class TransmissionSubtreeSlideA extends AbstractTreeOperator implements C
 
     private int intersectingEdges(Tree tree, NodeRef node, double height, BranchMapModel branchMap,
                                   AbstractCase partition, List<NodeRef> directChildren) {
-
         final NodeRef parent = tree.getParent(node);
-
         if (tree.getNodeHeight(parent) < height || branchMap.get(parent.getNumber())!=partition) return 0;
-
         if (tree.getNodeHeight(node) < height) {
             if (directChildren != null){
                 directChildren.add(node);
             }
             return 1;
         }
-
         int count = 0;
         for (int i = 0; i < tree.getChildCount(node); i++) {
             count += intersectingEdges(tree, tree.getChild(node, i), height, branchMap, partition, directChildren);
