@@ -1,3 +1,28 @@
+/*
+ * BirthDeathCollapseModel.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 /*
         This file is part of BEAST.
 
@@ -34,9 +59,7 @@ import dr.util.Author;
 import dr.util.Citable;
 import dr.util.Citation;
 
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Set;
+import java.util.*;
 import java.util.logging.Logger;
 
 
@@ -149,24 +172,31 @@ public class BirthDeathCollapseModel extends SpeciationModel implements Citable
         return Double.NEGATIVE_INFINITY;
     }
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SPECIES_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "DISSECT species delimitation model";
+    }
+
     @Override
     public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-
-        citations.add(new Citation(
-                new Author[]{
-                        new Author("Graham", "Jones"),
-                        new Author("Bengt", "Oxelman")
-                },
-                "DISSECT: an assignment-free Bayesian discovery method for species delimitation under the multispecies coalescent",
-                2014,
-                "BIORXIV/2014/003178",
-                -1,
-                -1,
-                -1,
-                Citation.Status.IN_SUBMISSION
-        ));
-
-        return citations;
+        return Collections.singletonList(
+                new Citation(
+                        new Author[]{
+                                new Author("Graham", "Jones"),
+                                new Author("Bengt", "Oxelman")
+                        },
+                        "DISSECT: an assignment-free Bayesian discovery method for species delimitation under the multispecies coalescent",
+                        2014,
+                        "BIORXIV/2014/003178",
+                        -1,
+                        -1,
+                        -1,
+                        Citation.Status.IN_SUBMISSION
+                ));
     }
 }
