@@ -38,8 +38,11 @@ import dr.inference.model.*;
 import dr.math.matrixAlgebra.Matrix;
 import dr.math.matrixAlgebra.RobustEigenDecomposition;
 import dr.math.matrixAlgebra.RobustSingularValueDecomposition;
+import dr.util.Citable;
+import dr.util.Citation;
+import dr.util.CommonCitations;
 
-import java.util.Arrays;
+import java.util.*;
 
 /**
  * <b>A general irreversible class for any
@@ -48,7 +51,7 @@ import java.util.Arrays;
  * @author Marc Suchard
  */
 
-public class ComplexSubstitutionModel extends AbstractSubstitutionModel implements Likelihood {
+public class ComplexSubstitutionModel extends AbstractSubstitutionModel implements Likelihood, Citable {
 
     public ComplexSubstitutionModel(String name, DataType dataType,
                                     FrequencyModel rootFreqModel, Parameter parameter) {
@@ -562,6 +565,11 @@ public class ComplexSubstitutionModel extends AbstractSubstitutionModel implemen
 
     }
 
+    @Override
+    public Set<Likelihood> getLikelihoodSet() {
+        return new HashSet<Likelihood>(Arrays.asList(this));
+    }
+
     @Override
     public boolean isUsed() {
         return super.isUsed() && isUsed;
@@ -575,4 +583,19 @@ public class ComplexSubstitutionModel extends AbstractSubstitutionModel implemen
 
     private double[] probability = null;
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Complex-diagonalizable, irreversible substitution model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CommonCitations.EDWARDS_2011_ANCIENT);
+    }
+
 }
\ No newline at end of file
