@@ -30,6 +30,11 @@ import dr.inference.distribution.LogLinearModel;
 import dr.inference.loggers.LogColumn;
 import dr.inference.model.BayesianStochasticSearchVariableSelection;
 import dr.inference.model.Model;
+import dr.util.Citation;
+import dr.util.CommonCitations;
+
+import java.util.Collections;
+import java.util.List;
 
 /**
  * <b>A irreversible class for any data type where
@@ -75,7 +80,18 @@ public class GLMSubstitutionModel extends ComplexSubstitutionModel {
             return 0;
         }
         return Double.NEGATIVE_INFINITY;
-    }   
+    }
+
+    @Override
+    public String getDescription() {
+        return "Generalized linear (model, GLM) substitution model"; // TODO Horrible; fix
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+
+        return Collections.singletonList(CommonCitations.LEMEY_2014_UNIFYING);
+    }
 
     private LogLinearModel glm;
     private double[] testProbabilities;    
