@@ -25,10 +25,17 @@
 
 package dr.evomodel.substmodel;
 
-import dr.evomodel.substmodel.NucModelType;
 import dr.inference.model.Parameter;
 import dr.inference.model.Statistic;
 import dr.inference.model.Variable;
+import dr.util.Author;
+import dr.util.Citable;
+import dr.util.Citation;
+
+import java.util.Collections;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
 
 
 /**
@@ -38,7 +45,7 @@ import dr.inference.model.Variable;
  * @author Andrew Rambaut
  * @version $Id: HKY.java,v 1.42 2005/09/23 13:17:59 rambaut Exp $
  */
-public class HKY extends AbstractNucleotideModel {
+public class HKY extends AbstractNucleotideModel implements Citable {
 
     /**
      * tsTv
@@ -376,4 +383,34 @@ public class HKY extends AbstractNucleotideModel {
         }
 
     };
+
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.SUBSTITUTION_MODELS;
+    }
+
+    @Override
+    public String getDescription() {
+        return "HKY nucleotide substitution model";
+    }
+
+    @Override
+    public List<Citation> getCitations() {
+        return Collections.singletonList(CITATION);
+    }
+
+
+    public static Citation CITATION = new Citation(
+            new Author[]{
+                    new Author("M", "Hasegowa"),
+                    new Author("H", "Kishino"),
+                    new Author("T", "Yano")
+            },
+            "Dating the human-ape splitting by a molecular clock of mitochondrial DNA",
+            1985,
+            "J. Mol. Evol.",
+            22,
+            160, 174,
+            Citation.Status.PUBLISHED
+    );
 }
