@@ -29,8 +29,7 @@ import dr.evolution.datatype.AminoAcids;
 import dr.util.Author;
 import dr.util.Citation;
 
-import java.util.Arrays;
-import java.util.List;
+import java.util.*;
 
 /**
  * LG model of amino acid evolution (Le and Gascuel, 2008)
@@ -310,11 +309,23 @@ public class LG extends EmpiricalRateMatrix.AbstractAminoAcid {
 		setEmpiricalFrequencies(f, "ARNDCQEGHILKMFPSTWYV");
 	}
 
-    public List<Citation> getCitations() {
-        return Arrays.asList(CITATION);
-    }
+	@Override
+	public Citation.Category getCategory() {
+		return Citation.Category.SUBSTITUTION_MODELS;
+	}
 
-    public static Citation CITATION = new Citation(
+	@Override
+	public String getDescription() {
+		return "LG amino acid substitution model";
+	}
+
+	@Override
+	public List<Citation> getCitations() {
+		return Collections.singletonList(CITATION);
+	}
+
+
+	public static Citation CITATION = new Citation(
             new Author[]{
                     new Author("S. Q.", "Le"),
                     new Author("O.", "Gascuel")
