@@ -1,7 +1,7 @@
 /*
  * TreeTraitParserUtilities.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -26,10 +26,7 @@
 package dr.evomodelxml.treelikelihood;
 
 import dr.evolution.tree.MultivariateTraitTree;
-import dr.inference.model.CompoundParameter;
-import dr.inference.model.MatrixParameter;
-import dr.inference.model.Parameter;
-import dr.inference.model.ParameterParser;
+import dr.inference.model.*;
 import dr.math.MathUtils;
 import dr.xml.*;
 
@@ -56,6 +53,7 @@ public class TreeTraitParserUtilities {
     public static final String JITTER = "jitter";
     public static final String WINDOW = "window";
     public static final String DUPLICATES = "duplicatesOnly";
+    public static final String STANDARDIZE = "standardize";
 
     public void randomize(Parameter trait, double[] lower, double[] upper) {
         // Draws each dimension in each trait from U[lower, upper)
@@ -67,6 +65,10 @@ public class TreeTraitParserUtilities {
         }
     }
 
+//    public void standardize(Parameter trait) {
+//        for (int i = 0; i < trait.)
+//    }
+
     public static ElementRule randomizeRules(boolean optional) {
         return new ElementRule(TreeTraitParserUtilities.RANDOMIZE, new XMLSyntaxRule[]{
                 AttributeRule.newDoubleRule(TreeTraitParserUtilities.RANDOMIZE_LOWER, true),
@@ -141,21 +143,26 @@ public class TreeTraitParserUtilities {
         }
     }
 
-    public boolean hasIdenticalTraits(Parameter trait, int dim) {
+    public boolean hasIdenticalTraits(Parameter trait, List<Integer> missingIndices, int dim) {
         int numTraits = trait.getDimension() / dim;
 
-        DoubleArray[] traitArray = new DoubleArray[numTraits];
+        List<DoubleArray> traitArray = new ArrayList<DoubleArray>();
         for (int i = 0; i < numTraits; i++) {
-            double[] x = new double[dim];
-            for (int j = 0; j < dim; j++) {
-                x[j] = trait.getParameterValue(i * dim + j);
+
+            if (!missingIndices.contains(i * dim)) { // TODO Assumes completely missing traits
+                double[] x = new double[dim];
+                for (int j = 0; j < dim; j++) {
+                    x[j] = trait.getParameterValue(i * dim + j);
+                }
+                traitArray.add(new DoubleArray(x, i));
             }
-            traitArray[i] = new DoubleArray(x, i);
         }
-        Arrays.sort(traitArray);
+
+        DoubleArray[] sortedTraits = traitArray.toArray(new DoubleArray[0]);
+        Arrays.sort(sortedTraits);
         // Mark duplicates
-        for (int i = 1; i < numTraits; i++) {
-            if (traitArray[i].compareTo(traitArray[i - 1]) == 0) {
+        for (int i = 1; i < sortedTraits.length; i++) {
+            if (sortedTraits[i].compareTo(sortedTraits[i - 1]) == 0) {
                 return true;
             }
         }
@@ -248,7 +255,7 @@ public class TreeTraitParserUtilities {
         List<Integer> missingIndices = null;
 
         boolean isMatrixParameter = false;
-        if (parameter instanceof MatrixParameter) {
+        if (parameter instanceof MatrixParameter || parameter instanceof FastMatrixParameter) {
             traitParameter = (CompoundParameter) parameter;
             isMatrixParameter = true;
         } else
