@@ -1,7 +1,7 @@
 /*
  * MCMC.java
  *
- * Copyright (C) 2002-2009 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -12,10 +12,10 @@
  * published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  *
- * BEAST is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with BEAST; if not, write to the
@@ -25,6 +25,8 @@
 
 package dr.inference.mcmc;
 
+import dr.inference.loggers.LogColumn;
+import dr.inference.loggers.Loggable;
 import dr.inference.loggers.Logger;
 import dr.inference.markovchain.MarkovChain;
 import dr.inference.markovchain.MarkovChainDelegate;
@@ -37,8 +39,10 @@ import dr.util.Identifiable;
 import dr.util.NumberFormatter;
 import dr.xml.Spawnable;
 
-import java.io.*;
-import java.util.Calendar;
+import java.io.File;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.PrintStream;
 
 /**
  * An MCMC analysis that estimates parameters of a probabilistic model.
@@ -47,7 +51,15 @@ import java.util.Calendar;
  * @author Andrew Rambaut
  * @version $Id: MCMC.java,v 1.41 2005/07/11 14:06:25 rambaut Exp $
  */
-public class MCMC implements Identifiable, Spawnable {
+public class MCMC implements Identifiable, Spawnable, Loggable {
+
+    public final static String LOAD_DUMP_FILE = "load.dump.file";
+    public final static String DUMP_STATE = "dump.state";
+    public final static String DUMP_EVERY = "dump.every";
+
+    // Experimental
+    public final static boolean TEST_CLONING = false;
+
 
     public MCMC(String id) {
         this.id = id;
@@ -141,17 +153,21 @@ public class MCMC implements Identifiable, Spawnable {
         //initialize transients
         currentState = 0;
 
-        // Does not seem to be in use (JH)
-/*
-        stepsPerReport = 1;
-        while ((getChainLength() / stepsPerReport) > 1000) {
-            stepsPerReport *= 2;
-        }*/
-
         for(MarkovChainDelegate delegate : delegates) {
             delegate.setup(options, schedule, mc);
         }
         this.delegates = delegates;
+
+        dumpStateFile = System.getProperty(LOAD_DUMP_FILE);
+        if (System.getProperty(DUMP_STATE) != null) {
+            long debugWriteState = Long.parseLong(System.getProperty(DUMP_STATE));
+            mc.addMarkovChainListener(new DebugChainListener(this, debugWriteState, false));
+        }
+        if (System.getProperty(DUMP_EVERY) != null) {
+            long debugWriteEvery = Long.parseLong(System.getProperty(DUMP_EVERY));
+            mc.addMarkovChainListener(new DebugChainListener(this, debugWriteEvery, true));
+        }
+
     }
 
     /**
@@ -196,9 +212,6 @@ public class MCMC implements Identifiable, Spawnable {
         chain();
     }
 
-    // Experimental
-    public final static boolean TEST_CLONING = false;
-
     /**
      * This method actually initiates the MCMC analysis.
      */
@@ -216,6 +229,27 @@ public class MCMC implements Identifiable, Spawnable {
         }
 
         if (!stopping) {
+            if (dumpStateFile != null) {
+                double[] savedLnL = new double[1];
+
+                long loadedState = DebugUtils.readStateFromFile(new File(dumpStateFile), savedLnL);
+
+                mc.setCurrentLength(loadedState);
+
+                double lnL = mc.evaluate();
+
+                DebugUtils.writeStateToFile(new File("tmp.dump"), loadedState, lnL);
+
+                if (lnL != savedLnL[0]) {
+                        throw new RuntimeException("Dumped lnL does not match loaded state: stored lnL: " + savedLnL[0] +
+                                ", recomputed lnL: " + lnL + " (difference " + (savedLnL[0] - lnL) + ")");
+                }
+
+//                for (Likelihood likelihood : Likelihood.CONNECTED_LIKELIHOOD_SET) {
+//                    System.err.println(likelihood.getId() + ": " + likelihood.getLogLikelihood());
+//                }
+            }
+
             mc.addMarkovChainListener(chainListener);
 
             for(MarkovChainDelegate delegate : delegates) {
@@ -239,19 +273,18 @@ public class MCMC implements Identifiable, Spawnable {
 
             if (TEST_CLONING) {
                 // TEST Code for cloning the MarkovChain to a file to distribute amongst processors
-                for(MarkovChainDelegate delegate : delegates) {
-                    mc.removeMarkovChainDelegate(delegate);
-                }
-                mc.removeMarkovChainListener(chainListener);
+
+                double lnL1 = mc.getCurrentScore();
 
                 // Write the MarkovChain out and back in again...
-                writeMarkovChainToFile(new File("beast.clone"), mc);
-                mc = readMarkovChainFromFile(new File("beast.clone"));
+                DebugUtils.writeStateToFile(new File("beast.state"), currentState, mc.getCurrentScore());
+                DebugUtils.readStateFromFile(new File("beast.state"), null);
 
-                mc.addMarkovChainListener(chainListener);
+                double lnL2 = mc.evaluate();
 
-                for(MarkovChainDelegate delegate : delegates) {
-                    mc.addMarkovChainDelegate(delegate);
+                if (lnL1 != lnL2) {
+                    throw new RuntimeException("Dumped lnL does not match loaded state: stored lnL: " + lnL1 +
+                            ", recomputed lnL: " + lnL2 + " (difference " + (lnL2 - lnL1) + ")");
                 }
                 // TEST Code end
             }
@@ -269,40 +302,36 @@ public class MCMC implements Identifiable, Spawnable {
         timer.stop();
     }
 
-    protected boolean writeMarkovChainToFile(File file, MarkovChain mc) {
-        OutputStream fileOut = null;
-        try {
-            fileOut = new FileOutputStream(file);
-            ObjectOutputStream out = new ObjectOutputStream(fileOut);
-            out.writeObject(mc);
-            out.close();
-            fileOut.close();
-        } catch (IOException ioe) {
-            System.err.println("Unable to write file: " + ioe.getMessage());
-        }
-        return true;
+    @Override
+    public LogColumn[] getColumns() {
+        return new LogColumn[] { new LogColumn() {
+            @Override
+            public void setLabel(String label) {
+            }
+
+            @Override
+            public String getLabel() {
+                return "time";
+            }
+
+            @Override
+            public void setMinimumWidth(int minimumWidth) {
+
+            }
+
+            @Override
+            public int getMinimumWidth() {
+                return 0;
+            }
+
+            @Override
+            public String getFormatted() {
+                return Double.toString(getTimer().toSeconds());
+            }
+        }   };
     }
 
-    protected MarkovChain readMarkovChainFromFile(File file) {
-        MarkovChain mc = null;
-        try {
-            FileInputStream fileIn =
-                    new FileInputStream(file);
-            ObjectInputStream in = new ObjectInputStream(fileIn);
-            mc = (MarkovChain) in.readObject();
-            in.close();
-            fileIn.close();
-        } catch (IOException ioe) {
-            System.err.println("Unable to read file: " + ioe.getMessage());
-        } catch (ClassNotFoundException cnfe) {
-            System.err.println("Unable to read file: " + cnfe.getMessage());
-            cnfe.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
-        }
-
-        return mc;
-    }
-
-    protected final MarkovChainListener chainListener = new MarkovChainListener() {
+    private final MarkovChainListener chainListener = new MarkovChainListener() {
 
         // MarkovChainListener interface *******************************************
         // for receiving messages from subordinate MarkovChain
@@ -384,22 +413,22 @@ public class MCMC implements Identifiable, Spawnable {
                 JointOperator jointOp = (JointOperator) op;
                 for (int k = 0; k < jointOp.getNumberOfSubOperators(); k++) {
                     out.println(formattedOperatorName(jointOp.getSubOperatorName(k))
-                            + formattedParameterString(jointOp.getSubOperator(k))
-                            + formattedCountString(op)
-                            + formattedTimeString(op)
-                            + formattedTimePerOpString(op)
-                            + formattedProbString(jointOp)
-                            + (options.useCoercion() ? "" : formattedDiagnostics(jointOp, MCMCOperator.Utils.getAcceptanceProbability(jointOp)))
+                                    + formattedParameterString(jointOp.getSubOperator(k))
+                                    + formattedCountString(op)
+                                    + formattedTimeString(op)
+                                    + formattedTimePerOpString(op)
+                                    + formattedProbString(jointOp)
+                                    + (options.useCoercion() ? "" : formattedDiagnostics(jointOp, MCMCOperator.Utils.getAcceptanceProbability(jointOp)))
                     );
                 }
             } else {
                 out.println(formattedOperatorName(op.getOperatorName())
-                        + formattedParameterString(op)
-                        + formattedCountString(op)
-                        + formattedTimeString(op)
-                        + formattedTimePerOpString(op)
-                        + formattedProbString(op)
-                        + (options.useCoercion() ? "" : formattedDiagnostics(op, MCMCOperator.Utils.getAcceptanceProbability(op)))
+                                + formattedParameterString(op)
+                                + formattedCountString(op)
+                                + formattedTimeString(op)
+                                + formattedTimePerOpString(op)
+                                + formattedProbString(op)
+                                + (options.useCoercion() ? "" : formattedDiagnostics(op, MCMCOperator.Utils.getAcceptanceProbability(op)))
                 );
             }
 
@@ -585,6 +614,8 @@ public class MCMC implements Identifiable, Spawnable {
 
     // PRIVATE TRANSIENTS
 
+    private String dumpStateFile = null;
+
     //private FileLogger operatorLogger = null;
     protected final boolean isAdapting = true;
     protected boolean stopping = false;
@@ -611,4 +642,3 @@ public class MCMC implements Identifiable, Spawnable {
 
     private String id = null;
 }
-
