@@ -1,7 +1,7 @@
 /*
  * MCMCMC.java
  *
- * Copyright (C) 2002-2007 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -376,54 +376,6 @@ public class MCMCMC implements Runnable {
         }
     }
 
-    public class BurninListener implements MarkovChainListener {
-
-        public BurninListener(long stateCount) {
-            this.stateCount = stateCount;
-            step = 0;
-            stepSize = (double) stateCount / 60.0;
-        }
-
-        /**
-         * Called to update the current model keepEvery states.
-         */
-        public synchronized void currentState(long state, Model currentModel) {
-
-            if (state == 0) {
-                System.out.println();
-                System.out.println("Pre-burnin (" + stateCount + " states)");
-                System.out.println("0              25             50             75            100");
-                System.out.println("|--------------|--------------|--------------|--------------|");
-                System.out.print("*");
-                step = 1;
-            }
-
-            if (state >= (int) Math.round(step * stepSize) && step <= 60) {
-                System.out.print("*");
-                System.out.flush();
-                step += 1;
-            }
-        }
-
-        /**
-         * Called when a new new best posterior state is found.
-         */
-        public synchronized void bestState(long state, Model bestModel) {
-        }
-
-        /**
-         * cleans up when the chain finishes (possibly early).
-         */
-        public synchronized void finished(long chainLength) {
-            System.out.println("*");
-            System.out.println();
-        }
-
-        long stateCount = 0;
-        double stepSize;
-        int step = 0;
-    }
-
     private final MarkovChainListener chainListener = new MarkovChainListener() {
 
         // MarkovChainListener interface *******************************************
@@ -533,21 +485,6 @@ public class MCMCMC implements Runnable {
         }
     }
 
-    //PRIVATE METHODS *****************************************
-    private boolean isPreBurninNeeded() {
-
-        if (mcmcOptions.useCoercion()) return true;
-
-        for (int i = 0; i < schedules[coldChain].getOperatorCount(); i++) {
-            MCMCOperator op = schedules[coldChain].getOperator(i);
-
-            if (op instanceof CoercableMCMCOperator) {
-                if (((CoercableMCMCOperator) op).getMode() == CoercionMode.COERCION_ON) return true;
-            }
-        }
-        return false;
-    }
-
     public void setShowOperatorAnalysis(boolean soa) {
         showOperatorAnalysis = soa;
     }
