@@ -1,7 +1,7 @@
 /*
  * MaskedParameter.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -40,9 +40,18 @@ public class MaskedParameter extends Parameter.Abstract implements VariableListe
 
     public MaskedParameter(Parameter parameter) {
         this.parameter = parameter;
+        parameter.addParameterListener(this);
+
         this.map = new int[parameter.getDimension()];
-        for (int i = 0; i < map.length; i++)
+        this.inverseMap = new int[parameter.getDimension()];
+
+        this.storedMap = new int[parameter.getDimension()];
+        this.storedInverseMap = new int[parameter.getDimension()];
+
+        for (int i = 0; i < map.length; i++) {
             map[i] = i;
+            inverseMap[i] = i;
+        }
         length = map.length;
     }
 
@@ -66,7 +75,10 @@ public class MaskedParameter extends Parameter.Abstract implements VariableListe
             final int maskValue = (int) maskParameter.getParameterValue(i);
             if (maskValue == equalValue) {
                 map[index] = i;
+                inverseMap[i] = index;
                 index++;
+            } else {
+                inverseMap[i] = -1; // Keep track of indices from parameter than do NOT correspond to entries in mask
             }
         }
         length = index;
@@ -81,29 +93,43 @@ public class MaskedParameter extends Parameter.Abstract implements VariableListe
 
     protected void storeValues() {
         parameter.storeParameterValues();
+        maskParameter.storeParameterValues();
+
+        System.arraycopy(map, 0, storedMap, 0, map.length);
+        System.arraycopy(inverseMap, 0, storedInverseMap, 0, inverseMap.length);
     }
 
     protected void restoreValues() {
         parameter.restoreParameterValues();
+        maskParameter.restoreParameterValues();
+
+        int[] tmp = storedMap;
+        storedMap = map;
+        map = tmp;
+
+        tmp = storedInverseMap;
+        storedInverseMap = inverseMap;
+        inverseMap = tmp;
     }
 
-    public void fireParameterChangedEvent() {
-        parameter.fireParameterChangedEvent();
-    }
+//    public void fireParameterChangedEvent() {
+//        parameter.fireParameterChangedEvent(); // TODO This could be wrong
+//    }
 
     protected void acceptValues() {
         parameter.acceptParameterValues();
+        maskParameter.acceptParameterValues();
     }
 
-    protected void adoptValues(Parameter source) {
-        parameter.adoptParameterValues(source);
-    }
+    protected void adoptValues(Parameter source) { throw new IllegalArgumentException("Not yet implemented"); }
 
     public double getParameterValue(int dim) {
+//        if (!isMapValid) updateMask();
         return parameter.getParameterValue(map[dim]);
     }
 
     public void setParameterValue(int dim, double value) {
+//        if (!isMapValid) updateMask();
         parameter.setParameterValue(map[dim], value);
     }
 
@@ -160,15 +186,24 @@ public class MaskedParameter extends Parameter.Abstract implements VariableListe
     public void variableChangedEvent(Variable variable, int index, ChangeType type) {
         if (variable == maskParameter) {
             updateMask();
-        } else {
-            System.err.println("Called by " + variable.getId());
-            throw new RuntimeException("Not yet implemented.");
+            fireParameterChangedEvent();
+        } else { // variable == parameter
+            if (index == -1) {
+                fireParameterChangedEvent();
+            } else if (inverseMap[index] != -1) {
+                fireParameterChangedEvent(inverseMap[index], type);
+            }
         }
     }
 
     private final Parameter parameter;
     private Parameter maskParameter;
-    private final int[] map;
+    private int[] map;
+    private int[] inverseMap;
+
+    private int[] storedMap;
+    private int[] storedInverseMap;
+
     private int length;
     private int equalValue;
 }
