@@ -1,7 +1,7 @@
 /*
  * Parameter.java
  *
- * Copyright (c) 2002-2013 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -26,13 +26,11 @@
 package dr.inference.model;
 
 import dr.inference.parallel.MPIServices;
+import dr.xml.Reportable;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.Set;
+import java.util.*;
 
 /**
  * Represents a multi-dimensional continuous parameter.
@@ -163,19 +161,25 @@ public interface Parameter extends Statistic, Variable<Double> {
 
     public void fireParameterChangedEvent();
 
+    public void fireParameterChangedEvent(int index, Parameter.ChangeType type);
+
     boolean isUsed();
 
+    public final static Set<Parameter> FULL_PARAMETER_SET = new LinkedHashSet<Parameter>();
+    public final static Set<Parameter> CONNECTED_PARAMETER_SET = new LinkedHashSet<Parameter>();
+
     /**
      * Abstract base class for parameters
      */
-    public abstract class Abstract extends Statistic.Abstract implements Parameter {
+    public abstract class Abstract extends Statistic.Abstract implements Parameter, Reportable {
 
         protected Abstract() {
+            FULL_PARAMETER_SET.add(this);
         }
 
         protected Abstract(final String name) {
             super(name);
-
+            FULL_PARAMETER_SET.add(this);
         }
 
         // **************************************************************
@@ -431,6 +435,34 @@ public interface Parameter extends Statistic, Variable<Double> {
             return buffer.toString();
         }
 
+        public String getReport() {
+            StringBuilder sb = new StringBuilder();
+            Bounds bounds = null;
+            try {
+                bounds = getBounds();
+            } catch (NullPointerException e) {
+                // Do nothing
+            }
+
+            for (int i = 0; i < getDimension(); ++i) {
+                if (getDimensionName(i) != null) {
+                    sb.append(getDimensionName(i)).append("=");
+                }
+                sb.append(String.valueOf(getParameterValue(i)));
+
+                if (bounds != null) {
+                    sb.append("[").append(String.valueOf(bounds.getLowerLimit(i)));
+                    sb.append(", ").append(String.valueOf(bounds.getUpperLimit(i))).append("]");
+                }
+
+                if (i < getDimension() - 1) {
+                    sb.append(", ");
+                }
+            }
+
+            return sb.toString();
+        }
+
         public Element createElement(Document document) {
             throw new IllegalArgumentException();
         }
@@ -672,7 +704,7 @@ public interface Parameter extends Statistic, Variable<Double> {
          */
         public void setParameterValueNotifyChangedAll(int i, double val) {
             values[i] = val;
-            fireParameterChangedEvent(i, Parameter.ChangeType.ALL_VALUES_CHANGED);
+            fireParameterChangedEvent(-1, Parameter.ChangeType.ALL_VALUES_CHANGED);
         }
 
         protected final void storeValues() {
@@ -781,5 +813,4 @@ public interface Parameter extends Statistic, Variable<Double> {
         private final double[] uppers, lowers;
     }
 
-    final static Set<Parameter> FULL_PARAMETER_SET = new HashSet<Parameter>();
 }
