@@ -1,3 +1,28 @@
+/*
+ * SimpleMetropolizedGibbsOperator.java
+ *
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ *
+ * This file is part of BEAST.
+ * See the NOTICE file distributed with this work for additional
+ * information regarding copyright ownership and licensing.
+ *
+ * BEAST is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ *  BEAST is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with BEAST; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 /**
  *
  */
@@ -112,7 +137,7 @@ public abstract class SimpleMetropolizedGibbsOperator extends SimpleOperator imp
         double logPosterior = 0.0;
 
         if (prior != null) {
-            final double logPrior = prior.getLogPrior(likelihood.getModel());
+            final double logPrior = prior.getLogPrior(likelihood.getModel()) * pathParameter;
 
             if (logPrior == Double.NEGATIVE_INFINITY) {
                 return Double.NEGATIVE_INFINITY;
@@ -121,7 +146,7 @@ public abstract class SimpleMetropolizedGibbsOperator extends SimpleOperator imp
             logPosterior += logPrior;
         }
 
-        final double logLikelihood = likelihood.getLogLikelihood()*pathParameter;
+        final double logLikelihood = likelihood.getLogLikelihood() * pathParameter;
 
         if (Double.isNaN(logLikelihood)) {
             return Double.NEGATIVE_INFINITY;
