@@ -1,7 +1,7 @@
 /*
  * SimpleOperatorSchedule.java
  *
- * Copyright (C) 2002-2006 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -30,6 +30,7 @@ import dr.inference.loggers.Loggable;
 import dr.inference.loggers.NumberColumn;
 import dr.math.MathUtils;
 
+import java.util.ArrayList;
 import java.util.List;
 import java.util.Vector;
 
@@ -45,7 +46,7 @@ public class SimpleOperatorSchedule implements OperatorSchedule, Loggable {
 	double totalWeight = 0;
 	int current = 0;
 	boolean sequential = false;
-	int optimizationSchedule = OperatorSchedule.DEFAULT_SCHEDULE;
+	OptimizationTransform optimizationSchedule = OptimizationTransform.DEFAULT;
 
 	public SimpleOperatorSchedule() {
 		operators = new Vector<MCMCOperator>();
@@ -114,14 +115,17 @@ public class SimpleOperatorSchedule implements OperatorSchedule, Loggable {
 
 	public double getOptimizationTransform(double d) {
         switch( optimizationSchedule ) {
-            case LOG_SCHEDULE:  return Math.log(d);
-            case SQRT_SCHEDULE: return Math.sqrt(d);
+			case DEFAULT:
+            case LOG:  return Math.log(d);
+            case SQRT: return Math.sqrt(d);
+			case LINEAR: return d;
+
+			default: throw new UnsupportedOperationException("Unknown enum value");
         }
-		return d;
 	}
 
-	public void setOptimizationSchedule(int schedule) {
-		optimizationSchedule = schedule;
+	public void setOptimizationSchedule(OptimizationTransform optimizationSchedule) {
+		this.optimizationSchedule = optimizationSchedule;
 	}
 
     public int getMinimumAcceptAndRejectCount() {
@@ -142,18 +146,22 @@ public class SimpleOperatorSchedule implements OperatorSchedule, Loggable {
 	 * @return the log columns.
 	 */
 	public LogColumn[] getColumns() {
-		LogColumn[] columns = new LogColumn[getOperatorCount()];
+		List<LogColumn> columnList = new ArrayList<LogColumn>();
 		for (int i = 0; i < getOperatorCount(); i++) {
 			MCMCOperator op = getOperator(i);
-			columns[i] = new OperatorColumn(op.getOperatorName(), op);
+			columnList.add(new OperatorAcceptanceColumn(op.getOperatorName(), op));
+			if (op instanceof CoercableMCMCOperator) {
+				columnList.add(new OperatorSizeColumn(op.getOperatorName() + "_size", (CoercableMCMCOperator)op));
+			}
 		}
+		LogColumn[] columns = columnList.toArray(new LogColumn[columnList.size()]);
 		return columns;
 	}
 
-    private class OperatorColumn extends NumberColumn {
+    private class OperatorAcceptanceColumn extends NumberColumn {
 		private final MCMCOperator op;
 
-		public OperatorColumn(String label, MCMCOperator op) {
+		public OperatorAcceptanceColumn(String label, MCMCOperator op) {
 			super(label);
 			this.op = op;
 		}
@@ -162,4 +170,17 @@ public class SimpleOperatorSchedule implements OperatorSchedule, Loggable {
 			return MCMCOperator.Utils.getAcceptanceProbability(op);
 		}
 	}
+
+	private class OperatorSizeColumn extends NumberColumn {
+		private final CoercableMCMCOperator op;
+
+		public OperatorSizeColumn(String label, CoercableMCMCOperator op) {
+			super(label);
+			this.op = op;
+		}
+
+		public double getDoubleValue() {
+			return op.getRawParameter();
+		}
+	}
 }
