@@ -32,10 +32,7 @@ import dr.xml.*;
 
 import java.io.File;
 import java.io.FileNotFoundException;
-import java.util.ArrayList;
-import java.util.Iterator;
-import java.util.List;
-import java.util.StringTokenizer;
+import java.util.*;
 
 /**
  * @author Philippe Lemey
@@ -333,19 +330,19 @@ public class DnDsPerSiteAnalysis implements Citable {
         return sb.toString();
     }
 
+    @Override
+    public Citation.Category getCategory() {
+        return Citation.Category.COUNTING_PROCESSES;
+    }
+
+    @Override
+    public String getDescription() {
+        return "Renaissance counting";
+    }
+
+    @Override
     public List<Citation> getCitations() {
-        List<Citation> citations = new ArrayList<Citation>();
-        citations.add(
-                new Citation(
-                        new Author[]{
-                                new Author("P", "Lemey"),
-                                new Author("VN", "Minin"),
-                                new Author("MA", "Suchard")
-                        },
-                        Citation.Status.IN_PREPARATION
-                )
-        );
-        return citations;
+        return Collections.singletonList(CommonCitations.LEMEY_2012_RENAISSANCE);
     }
 
     private class OutputFormat {
