@@ -1,7 +1,7 @@
 /*
  * TraceList.java
  *
- * Copyright (C) 2002-2006 Alexei Drummond and Andrew Rambaut
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -82,7 +82,7 @@ public interface TraceList {
     /**
      * @return the last state in the chain
      */
-    int getMaxState();
+    long getMaxState();
 
     boolean isIncomplete();
 
