@@ -1,7 +1,7 @@
 /*
  * MultivariateNormalDistribution.java
  *
- * Copyright (c) 2002-2014 Alexei Drummond, Andrew Rambaut and Marc Suchard
+ * Copyright (c) 2002-2015 Alexei Drummond, Andrew Rambaut and Marc Suchard
  *
  * This file is part of BEAST.
  * See the NOTICE file distributed with this work for additional
@@ -25,6 +25,7 @@
 
 package dr.math.distributions;
 
+import dr.inference.model.Likelihood;
 import dr.math.MathUtils;
 import dr.math.matrixAlgebra.*;
 
@@ -41,9 +42,26 @@ public class MultivariateNormalDistribution implements MultivariateDistribution,
     private double[][] cholesky = null;
     private Double logDet = null;
 
+    private final boolean hasSinglePrecision;
+    private final double singlePrecision;
+
     public MultivariateNormalDistribution(double[] mean, double[][] precision) {
         this.mean = mean;
         this.precision = precision;
+        this.hasSinglePrecision = false;
+        this.singlePrecision = 1.0;
+    }
+
+    public MultivariateNormalDistribution(double[] mean, double singlePrecision) {
+        this.mean = mean;
+        this.hasSinglePrecision = true;
+        this.singlePrecision = singlePrecision;
+
+        final int dim = mean.length;
+        this.precision = new double[dim][dim];
+        for (int i = 0; i < dim; ++i) {
+            this.precision[i][i] = singlePrecision;
+        }
     }
 
     public String getType() {
@@ -132,7 +150,11 @@ public class MultivariateNormalDistribution implements MultivariateDistribution,
     }
 
     public double logPdf(double[] x) {
-        return logPdf(x, mean, precision, getLogDet(), 1.0);
+        if (hasSinglePrecision) {
+            return logPdf(x, mean, singlePrecision, 1.0);
+        } else {
+            return logPdf(x, mean, precision, getLogDet(), 1.0);
+        }
     }
 
     // scale only modifies precision
@@ -218,7 +240,6 @@ public class MultivariateNormalDistribution implements MultivariateDistribution,
         return result;
     }
 
-
     public static void nextMultivariateNormalCholesky(double[] mean, double[][] cholesky, double sqrtScale, double[] result) {
 
         final int dim = mean.length;
@@ -237,6 +258,25 @@ public class MultivariateNormalDistribution implements MultivariateDistribution,
         }
     }
 
+    public static void nextMultivariateNormalCholesky(final double[] mean, final int meanOffset, final double[][] cholesky,
+                                                      final double sqrtScale, final double[] result, final int resultOffset,
+                                                      final double[] epsilon) {
+
+        final int dim = epsilon.length;
+
+        System.arraycopy(mean, meanOffset, result, resultOffset, dim);
+
+        for (int i = 0; i < dim; i++)
+            epsilon[i] = MathUtils.nextGaussian() * sqrtScale;
+
+        for (int i = 0; i < dim; i++) {
+            for (int j = 0; j <= i; j++) {
+                result[resultOffset + i] += cholesky[i][j] * epsilon[j];
+                // caution: decomposition returns lower triangular
+            }
+        }
+    }
+
     // TODO should be a junit test
     public static void main(String[] args) {
         testPdf();
@@ -303,4 +343,17 @@ public class MultivariateNormalDistribution implements MultivariateDistribution,
         double[] v = (double[]) x;
         return logPdf(v);
     }
+
+    @Override
+    public Likelihood getLikelihood() {
+        return null;
+    }
+
+    @Override
+    public int getDimension() { return mean.length; }
+
+    @Override
+    public double[][] getPrecisionMatrix() {
+        return precision;
+    }
 }
