@@ -30,8 +30,8 @@ package dr.math.distributions;
  */
 public interface RandomGenerator {
 
-    public Object nextRandom();
+    Object nextRandom();
 
-    public double logPdf(Object x);
+    double logPdf(Object x);
 
 }
