@@ -29,8 +29,7 @@ import dr.inference.model.Likelihood;
 import dr.inference.model.Model;
 import dr.inference.model.Parameter;
 import dr.inferencexml.loggers.LoggerParser;
-import dr.util.FileHelpers;
-import dr.util.Identifiable;
+import dr.util.*;
 import org.w3c.dom.*;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
@@ -108,7 +107,7 @@ public class XMLParser {
 
         XMLObject xo = new XMLObject(null /*, objectStore*/);
         xo.setNativeObject(object);
-        store.put(name, xo);
+        objectStore.put(name, xo);
     }
 
     /**
@@ -147,7 +146,7 @@ public class XMLParser {
         }
     }
 
-    public ObjectStore parse(Reader reader, boolean run)
+    public Map<String, XMLObject> parse(Reader reader, boolean run)
             throws java.io.IOException,
             org.xml.sax.SAXException,
             dr.xml.XMLParseException,
@@ -218,7 +217,7 @@ public class XMLParser {
             }
 
 
-            XMLObject restoredXMLObject = (XMLObject) store.get(idref);
+            XMLObject restoredXMLObject = (XMLObject) objectStore.get(idref);
             if (index != -1) {
 
                 if (restoredXMLObject.getNativeObject() instanceof List) {
@@ -267,7 +266,7 @@ public class XMLParser {
                 repeats = Integer.parseInt(e.getAttribute("count"));
             }
 
-            XMLObject xo = new XMLObject(e /*, objectStore*/);
+            XMLObject xo = new XMLObject(e);
 
             final XMLObjectParser parser = doParse ? parserStore.get(xo.getName()) : null;
 
@@ -308,7 +307,7 @@ public class XMLParser {
                 id = e.getAttribute(ID);
             }
 
-            if ((id != null) && store.get(id) != null) {
+            if ((id != null) && objectStore.get(id) != null) {
                 throw new XMLParseException("Object with Id=" + id + " already exists");
             }
 
@@ -316,10 +315,14 @@ public class XMLParser {
             if (parser != null) {
                 obj = parser.parseXMLObject(xo, id, objectStore, strictXML);
 
-                if (id != null && obj instanceof Identifiable) {
+                if (obj instanceof Identifiable) {
                     ((Identifiable) obj).setId(id);
                 }
 
+                if (obj instanceof Citable) {
+                    addCitable((Citable)obj);
+                }
+
                 if (obj instanceof Likelihood) {
                     Likelihood.FULL_LIKELIHOOD_SET.add((Likelihood) obj);
                 } else if (obj instanceof Model) {
@@ -334,7 +337,7 @@ public class XMLParser {
             if (id != null) {
                 if (verbose) System.out.println("  Storing " + xo.getName() + " with id=" + id);
 
-                store.put(id, xo);
+                objectStore.put(id, xo);
             }
 
             if (run) {
@@ -353,6 +356,9 @@ public class XMLParser {
                         waitForThread((Thread) thread1);
                     }
                 } else if (obj instanceof Runnable && !concurrent) {
+
+                    executingRunnable();
+
                     if (obj instanceof Spawnable && !((Spawnable) obj).getSpawnable()) {
                         ((Spawnable) obj).run();
                     } else {
@@ -369,6 +375,14 @@ public class XMLParser {
         }
     }
 
+    protected void executingRunnable() {
+        // do nothing - for overriding by subclasses
+    }
+
+    public Map<Pair<String, String>, List<Citation>> getCitationStore() {
+        return citationStore;
+    }
+
     public static FileReader getFileReader(XMLObject xo, String attributeName) throws XMLParseException {
         if (xo.hasAttribute(attributeName)) {
             final File inFile = getFileHandle(xo, attributeName);
@@ -467,6 +481,9 @@ public class XMLParser {
         return logFile;
     }
 
+    public Map<String, XMLObject> getObjectStore() {
+        return objectStore;
+    }
 
     public class ArrayParser extends AbstractXMLObjectParser {
 
@@ -514,46 +531,62 @@ public class XMLParser {
         }
     }
 
-    //anonymous object store class
-    private final ObjectStore objectStore = new ObjectStore() {
-        public Object getObjectById(Object uid) throws ObjectNotFoundException {
-            XMLObject obj = (XMLObject) store.get(uid);
-            if (obj == null) throw new ObjectNotFoundException("Object with uid=" + uid + " not found in ObjectStore");
-            if (obj.hasNativeObject()) return obj.getNativeObject();
-            return obj;
-        }
+//    //anonymous object store class
+//    private final ObjectStore objectStore = new ObjectStore() {
+//        public Object getObjectById(Object uid) throws ObjectNotFoundException {
+//            XMLObject obj = (XMLObject) store.get(uid);
+//            if (obj == null) throw new ObjectNotFoundException("Object with uid=" + uid + " not found in ObjectStore");
+//            if (obj.hasNativeObject()) return obj.getNativeObject();
+//            return obj;
+//        }
+//
+//        public boolean hasObjectId(Object uid) {
+//            Object obj = store.get(uid);
+//            return (obj != null);
+//        }
+//
+//        public Set getIdSet() {
+//            return store.keySet();
+//        }
+//
+//        public Collection getObjects() {
+//            return store.values();
+//        }
+//
+////        public void addIdentifiableObject(Identifiable obj, boolean force) {
+////
+////            String id = obj.getId();
+////            if (id == null) throw new IllegalArgumentException("Object must have a non-null identifier.");
+////
+////            if (force) {
+////                store.put(id, obj);
+////            } else {
+////                if (store.get(id) == null) {
+////                    store.put(id, obj);
+////                }
+////            }
+////        }
+//    };
 
-        public boolean hasObjectId(Object uid) {
-            Object obj = store.get(uid);
-            return (obj != null);
-        }
-
-        public Set getIdSet() {
-            return store.keySet();
-        }
-
-        public Collection getObjects() {
-            return store.values();
-        }
-
-        public void addIdentifiableObject(Identifiable obj, boolean force) {
-
-            String id = obj.getId();
-            if (id == null) throw new IllegalArgumentException("Object must have a non-null identifier.");
-
-            if (force) {
-                store.put(id, obj);
-            } else {
-                if (store.get(id) == null) {
-                    store.put(id, obj);
-                }
+    public void addCitable(Citable citable) {
+        // remove 'In prep' citations
+        List<Citation> citationList = new LinkedList<Citation>();
+        for (Citation citation : citable.getCitations()) {
+            if (citation.getStatus() != Citation.Status.IN_PREPARATION) {
+                citationList.add(citation);
             }
         }
-    };
+        if (citationList.size() > 0) {
+            Pair<String, String> pair = new Pair<String, String>(citable.getCategory().toString(),
+                    citable.getDescription());
+            citationStore.put(pair, citationList);
+        }
+    }
 
-
-    private final Hashtable<String, Object> store = new Hashtable<String, Object>();
-    private final TreeMap<String, XMLObjectParser> parserStore = new TreeMap<String, XMLObjectParser>(new ParserComparator());
+    //    private final Hashtable<String, XMLObject> store = new Hashtable<String, XMLObject>();
+    private final Map<String, XMLObjectParser> parserStore = new TreeMap<String, XMLObjectParser>(new ParserComparator());
+    private final Map<String, XMLObject> objectStore = new LinkedHashMap<String, XMLObject>();
+    private final Map<Pair<String, String>, List<Citation>> citationStore = new LinkedHashMap<Pair<String, String>, List<Citation>>();
     private boolean concurrent = false;
     private XMLObject root = null;
 
@@ -596,6 +629,7 @@ public class XMLParser {
             return name1.compareTo(name2);
         }
     }
+
 }
 
 
